#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .interpolate_flow_cp import interpolate_flow_cp
from .interpolate_flow_density import interpolate_flow_density
from .interpolate_flow_solution_gradients import interpolate_flow_solution_gradients
from .interpolate_flow_viscosity import interpolate_flow_viscosity
from .interpolate_temperature import interpolate_temperature
from .zero_nodal_velocities_on_walls import zero_nodal_velocities_on_walls
class interpolation(Group):
    """
    Main menu holding options to enable/disable interpolation of flow data to the particle position.
    """

    fluent_name = "interpolation"

    child_names = \
        ['interpolate_flow_cp', 'interpolate_flow_density',
         'interpolate_flow_solution_gradients', 'interpolate_flow_viscosity',
         'interpolate_temperature', 'zero_nodal_velocities_on_walls']

    interpolate_flow_cp: interpolate_flow_cp = interpolate_flow_cp
    """
    interpolate_flow_cp child of interpolation.
    """
    interpolate_flow_density: interpolate_flow_density = interpolate_flow_density
    """
    interpolate_flow_density child of interpolation.
    """
    interpolate_flow_solution_gradients: interpolate_flow_solution_gradients = interpolate_flow_solution_gradients
    """
    interpolate_flow_solution_gradients child of interpolation.
    """
    interpolate_flow_viscosity: interpolate_flow_viscosity = interpolate_flow_viscosity
    """
    interpolate_flow_viscosity child of interpolation.
    """
    interpolate_temperature: interpolate_temperature = interpolate_temperature
    """
    interpolate_temperature child of interpolation.
    """
    zero_nodal_velocities_on_walls: zero_nodal_velocities_on_walls = zero_nodal_velocities_on_walls
    """
    zero_nodal_velocities_on_walls child of interpolation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .intake_fan_child import intake_fan_child

class intake_fan(NamedObject[intake_fan_child], _NonCreatableNamedObjectMixin[intake_fan_child]):
    """
    'intake_fan' child.
    """

    fluent_name = "intake-fan"

    child_object_type: intake_fan_child = intake_fan_child
    """
    child_object_type of intake_fan.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .method_4 import method
from .type_1 import type
from .frequency_1 import frequency
class two_session_coupling(Group):
    """
    'two_session_coupling' child.
    """

    fluent_name = "two-session-coupling"

    child_names = \
        ['method', 'type', 'frequency']

    method: method = method
    """
    method child of two_session_coupling.
    """
    type: type = type
    """
    type child of two_session_coupling.
    """
    frequency: frequency = frequency
    """
    frequency child of two_session_coupling.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .phase_child_3 import phase_child

class phase(NamedObject[phase_child], _NonCreatableNamedObjectMixin[phase_child]):
    """
    'phase' child.
    """

    fluent_name = "phase"

    child_object_type: phase_child = phase_child
    """
    child_object_type of phase.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .auto import auto
from .set_3 import set
from .combine_partition import combine_partition
from .merge_clusters import merge_clusters
from .method_3 import method
from .print_partitions import print_partitions
from .print_active_partitions import print_active_partitions
from .print_stored_partitions import print_stored_partitions
from .reorder_partitions import reorder_partitions
from .reorder_partitions_to_architecture import reorder_partitions_to_architecture
from .smooth_partition import smooth_partition
from .use_stored_partitions import use_stored_partitions
class partition(Group):
    """
    Enter the partition domain menu.
    """

    fluent_name = "partition"

    child_names = \
        ['auto', 'set']

    auto: auto = auto
    """
    auto child of partition.
    """
    set: set = set
    """
    set child of partition.
    """
    command_names = \
        ['combine_partition', 'merge_clusters', 'method', 'print_partitions',
         'print_active_partitions', 'print_stored_partitions',
         'reorder_partitions', 'reorder_partitions_to_architecture',
         'smooth_partition', 'use_stored_partitions']

    combine_partition: combine_partition = combine_partition
    """
    combine_partition command of partition.
    """
    merge_clusters: merge_clusters = merge_clusters
    """
    merge_clusters command of partition.
    """
    method: method = method
    """
    method command of partition.
    """
    print_partitions: print_partitions = print_partitions
    """
    print_partitions command of partition.
    """
    print_active_partitions: print_active_partitions = print_active_partitions
    """
    print_active_partitions command of partition.
    """
    print_stored_partitions: print_stored_partitions = print_stored_partitions
    """
    print_stored_partitions command of partition.
    """
    reorder_partitions: reorder_partitions = reorder_partitions
    """
    reorder_partitions command of partition.
    """
    reorder_partitions_to_architecture: reorder_partitions_to_architecture = reorder_partitions_to_architecture
    """
    reorder_partitions_to_architecture command of partition.
    """
    smooth_partition: smooth_partition = smooth_partition
    """
    smooth_partition command of partition.
    """
    use_stored_partitions: use_stored_partitions = use_stored_partitions
    """
    use_stored_partitions command of partition.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class solve_flow_last(Boolean):
    """
    Solve flow equation at the end of iteration as an alternative.
    """

    fluent_name = "solve-flow-last?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .cell_registers_child import cell_registers_child

class cell_registers(NamedObject[cell_registers_child], _CreatableNamedObjectMixin[cell_registers_child]):
    """
    'cell_registers' child.
    """

    fluent_name = "cell-registers"

    child_object_type: cell_registers_child = cell_registers_child
    """
    child_object_type of cell_registers.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .injections_child import injections_child

class injections(NamedObject[injections_child], _CreatableNamedObjectMixin[injections_child]):
    """
    'injections' child.
    """

    fluent_name = "injections"

    child_object_type: injections_child = injections_child
    """
    child_object_type of injections.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .tsv_file_name import tsv_file_name
class import_(Command):
    """
    Import execute-commands from a TSV file.
    
    Parameters
    ----------
        tsv_file_name : str
            'tsv_file_name' child.
    
    """

    fluent_name = "import"

    argument_names = \
        ['tsv_file_name']

    tsv_file_name: tsv_file_name = tsv_file_name
    """
    tsv_file_name argument of import_.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .use_enhancement import use_enhancement
from .aspect_ratio_1 import aspect_ratio
class stretched_mesh_enhancement(Group):
    """
    Enhancement for mesh with stretched cells.
    """

    fluent_name = "stretched-mesh-enhancement"

    child_names = \
        ['use_enhancement', 'aspect_ratio']

    use_enhancement: use_enhancement = use_enhancement
    """
    use_enhancement child of stretched_mesh_enhancement.
    """
    aspect_ratio: aspect_ratio = aspect_ratio
    """
    aspect_ratio child of stretched_mesh_enhancement.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .char_intrinsic_reactivity import char_intrinsic_reactivity
from .carbon_content_percentage import carbon_content_percentage
class cbk(Group):
    """
    'cbk' child.
    """

    fluent_name = "cbk"

    child_names = \
        ['option', 'char_intrinsic_reactivity', 'carbon_content_percentage']

    option: option = option
    """
    option child of cbk.
    """
    char_intrinsic_reactivity: char_intrinsic_reactivity = char_intrinsic_reactivity
    """
    char_intrinsic_reactivity child of cbk.
    """
    carbon_content_percentage: carbon_content_percentage = carbon_content_percentage
    """
    carbon_content_percentage child of cbk.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .kernel import kernel
from .gaussian_factor import gaussian_factor
class averaging_kernel(Group):
    """
    'averaging_kernel' child.
    """

    fluent_name = "averaging-kernel"

    child_names = \
        ['kernel', 'gaussian_factor']

    kernel: kernel = kernel
    """
    kernel child of averaging_kernel.
    """
    gaussian_factor: gaussian_factor = gaussian_factor
    """
    gaussian_factor child of averaging_kernel.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .mass_flow_inlet_child import mass_flow_inlet_child

class mass_flow_outlet(NamedObject[mass_flow_inlet_child], _NonCreatableNamedObjectMixin[mass_flow_inlet_child]):
    """
    'mass_flow_outlet' child.
    """

    fluent_name = "mass-flow-outlet"

    child_object_type: mass_flow_inlet_child = mass_flow_inlet_child
    """
    child_object_type of mass_flow_outlet.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class rgp_table(String):
    """
    Select RGP Table Data Set.
    """

    fluent_name = "rgp-table"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class heat_flux_relaxation_factor(Real):
    """
    Under-relaxation factor for boiling heat flux.
    """

    fluent_name = "heat-flux-relaxation-factor"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class unstructured_var_presto_scheme(Boolean):
    """
    Enable/disable use of unstructured variant of PRESTO pressure scheme.
    """

    fluent_name = "unstructured-var-presto-scheme?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .change_type import change_type
from .porous_jump_child import porous_jump_child

class porous_jump(NamedObject[porous_jump_child], _CreatableNamedObjectMixin[porous_jump_child]):
    """
    'porous_jump' child.
    """

    fluent_name = "porous-jump"

    command_names = \
        ['change_type']

    change_type: change_type = change_type
    """
    change_type command of porous_jump.
    """
    child_object_type: porous_jump_child = porous_jump_child
    """
    child_object_type of porous_jump.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .iterate_1 import iterate
from .dual_time_iterate_1 import dual_time_iterate
class solve(Group):
    """
    'solve' child.
    """

    fluent_name = "solve"

    command_names = \
        ['iterate', 'dual_time_iterate']

    iterate: iterate = iterate
    """
    iterate command of solve.
    """
    dual_time_iterate: dual_time_iterate = dual_time_iterate
    """
    dual_time_iterate command of solve.
    """



"""Module containing class encapsulating Fluent connection.

**********PRESENTLY SAME AS MESHING WITHOUT THE SWITCH TO SOLVER***********
"""


from ansys.fluent.core.fluent_connection import _FluentConnection
from ansys.fluent.core.session import _BaseSession
from ansys.fluent.core.session_base_meshing import _BaseMeshing
from ansys.fluent.core.utils.data_transfer import transfer_case


class PureMeshing(_BaseSession):
    """Encapsulates a Fluent - Pure Meshing session connection.
    PureMeshing(_BaseSession) holds the top-level objects
    for meshing TUI and various meshing datamodel API calls.
    In pure-meshing mode, switch to solver is not available.
    Public attributes of this class or extracted from the _BaseMeshing
    class"""

    def __init__(self, fluent_connection: _FluentConnection):
        super(PureMeshing, self).__init__(fluent_connection=fluent_connection)
        self._base_meshing = _BaseMeshing(self.execute_tui, fluent_connection)

    @property
    def tui(self):
        """Instance of ``main_menu`` on which Fluent's SolverTUI methods can be
        executed."""
        return self._base_meshing.tui

    @property
    def meshing(self):
        """meshing datamodel root."""
        return self._base_meshing.meshing

    @property
    def workflow(self):
        """workflow datamodel root."""
        return self._base_meshing.workflow

    @property
    def PartManagement(self):
        """PartManagement datamodel root."""
        return self._base_meshing.PartManagement

    @property
    def PMFileManagement(self):
        """PMFileManagement datamodel root."""
        return self._base_meshing.PMFileManagement

    @property
    def preferences(self):
        """preferences datamodel root."""
        return self._base_meshing.preferences

    def transfer_mesh_to_solvers(
        self,
        solvers,
        file_type: str = "case",
        file_name_stem: str = None,
        num_files_to_try: int = 1,
        clean_up_mesh_file: bool = True,
        overwrite_previous: bool = True,
    ):
        """Transfer mesh to Fluent solver instances.

        Parameters
        ----------
        solvers : iterable
            Sequence of solver instances
        file_type : str, default "case"
            "case" or "mesh"
        file_name_stem : str
            Optional file name stem
        num_files_to_try : int, default 1
            Optional number of files to try to write,
            each with a different generated name.
            Defaults to 1
        clean_up_mesh_file: bool, default True
            Whether to remove the file at the end
        overwrite_previous: bool, default True
            Whether to overwrite the file if it already exists
        Returns
        -------
        None
        """
        transfer_case(
            self,
            solvers,
            file_type,
            file_name_stem,
            num_files_to_try,
            clean_up_mesh_file,
            overwrite_previous,
        )



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .fixed_cycle_parameters import fixed_cycle_parameters
from .coarsening_parameters import coarsening_parameters
from .smoother_type import smoother_type
class scalar_parameters(Group):
    """
    'scalar_parameters' child.
    """

    fluent_name = "scalar-parameters"

    child_names = \
        ['fixed_cycle_parameters', 'coarsening_parameters', 'smoother_type']

    fixed_cycle_parameters: fixed_cycle_parameters = fixed_cycle_parameters
    """
    fixed_cycle_parameters child of scalar_parameters.
    """
    coarsening_parameters: coarsening_parameters = coarsening_parameters
    """
    coarsening_parameters child of scalar_parameters.
    """
    smoother_type: smoother_type = smoother_type
    """
    smoother_type child of scalar_parameters.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .phase_15 import phase
from .geom_disable import geom_disable
from .geom_dir_spec import geom_dir_spec
from .geom_dir_x import geom_dir_x
from .geom_dir_y import geom_dir_y
from .geom_dir_z import geom_dir_z
from .geom_levels import geom_levels
from .geom_bgthread import geom_bgthread
from .porous_jump_turb_wall_treatment import porous_jump_turb_wall_treatment
from .alpha import alpha
from .dm import dm
from .c2 import c2
from .thermal_ctk import thermal_ctk
from .solar_fluxes import solar_fluxes
from .v_absp import v_absp
from .ir_absp import ir_absp
from .ir_trans import ir_trans
from .v_trans import v_trans
from .dpm_bc_type import dpm_bc_type
from .dpm_bc_collision_partner import dpm_bc_collision_partner
from .reinj_inj import reinj_inj
from .dpm_bc_udf import dpm_bc_udf
from .strength import strength
from .jump_adhesion import jump_adhesion
from .adhesion_constrained import adhesion_constrained
from .adhesion_angle import adhesion_angle
from .x_displacement_type import x_displacement_type
from .x_displacement_value import x_displacement_value
from .y_displacement_type import y_displacement_type
from .y_displacement_value import y_displacement_value
from .z_displacement_type import z_displacement_type
from .z_displacement_value import z_displacement_value
class porous_jump_child(Group):
    """
    'child_object_type' of porous_jump.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread',
         'porous_jump_turb_wall_treatment', 'alpha', 'dm', 'c2',
         'thermal_ctk', 'solar_fluxes', 'v_absp', 'ir_absp', 'ir_trans',
         'v_trans', 'dpm_bc_type', 'dpm_bc_collision_partner', 'reinj_inj',
         'dpm_bc_udf', 'strength', 'jump_adhesion', 'adhesion_constrained',
         'adhesion_angle', 'x_displacement_type', 'x_displacement_value',
         'y_displacement_type', 'y_displacement_value', 'z_displacement_type',
         'z_displacement_value']

    phase: phase = phase
    """
    phase child of porous_jump_child.
    """
    geom_disable: geom_disable = geom_disable
    """
    geom_disable child of porous_jump_child.
    """
    geom_dir_spec: geom_dir_spec = geom_dir_spec
    """
    geom_dir_spec child of porous_jump_child.
    """
    geom_dir_x: geom_dir_x = geom_dir_x
    """
    geom_dir_x child of porous_jump_child.
    """
    geom_dir_y: geom_dir_y = geom_dir_y
    """
    geom_dir_y child of porous_jump_child.
    """
    geom_dir_z: geom_dir_z = geom_dir_z
    """
    geom_dir_z child of porous_jump_child.
    """
    geom_levels: geom_levels = geom_levels
    """
    geom_levels child of porous_jump_child.
    """
    geom_bgthread: geom_bgthread = geom_bgthread
    """
    geom_bgthread child of porous_jump_child.
    """
    porous_jump_turb_wall_treatment: porous_jump_turb_wall_treatment = porous_jump_turb_wall_treatment
    """
    porous_jump_turb_wall_treatment child of porous_jump_child.
    """
    alpha: alpha = alpha
    """
    alpha child of porous_jump_child.
    """
    dm: dm = dm
    """
    dm child of porous_jump_child.
    """
    c2: c2 = c2
    """
    c2 child of porous_jump_child.
    """
    thermal_ctk: thermal_ctk = thermal_ctk
    """
    thermal_ctk child of porous_jump_child.
    """
    solar_fluxes: solar_fluxes = solar_fluxes
    """
    solar_fluxes child of porous_jump_child.
    """
    v_absp: v_absp = v_absp
    """
    v_absp child of porous_jump_child.
    """
    ir_absp: ir_absp = ir_absp
    """
    ir_absp child of porous_jump_child.
    """
    ir_trans: ir_trans = ir_trans
    """
    ir_trans child of porous_jump_child.
    """
    v_trans: v_trans = v_trans
    """
    v_trans child of porous_jump_child.
    """
    dpm_bc_type: dpm_bc_type = dpm_bc_type
    """
    dpm_bc_type child of porous_jump_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner = dpm_bc_collision_partner
    """
    dpm_bc_collision_partner child of porous_jump_child.
    """
    reinj_inj: reinj_inj = reinj_inj
    """
    reinj_inj child of porous_jump_child.
    """
    dpm_bc_udf: dpm_bc_udf = dpm_bc_udf
    """
    dpm_bc_udf child of porous_jump_child.
    """
    strength: strength = strength
    """
    strength child of porous_jump_child.
    """
    jump_adhesion: jump_adhesion = jump_adhesion
    """
    jump_adhesion child of porous_jump_child.
    """
    adhesion_constrained: adhesion_constrained = adhesion_constrained
    """
    adhesion_constrained child of porous_jump_child.
    """
    adhesion_angle: adhesion_angle = adhesion_angle
    """
    adhesion_angle child of porous_jump_child.
    """
    x_displacement_type: x_displacement_type = x_displacement_type
    """
    x_displacement_type child of porous_jump_child.
    """
    x_displacement_value: x_displacement_value = x_displacement_value
    """
    x_displacement_value child of porous_jump_child.
    """
    y_displacement_type: y_displacement_type = y_displacement_type
    """
    y_displacement_type child of porous_jump_child.
    """
    y_displacement_value: y_displacement_value = y_displacement_value
    """
    y_displacement_value child of porous_jump_child.
    """
    z_displacement_type: z_displacement_type = z_displacement_type
    """
    z_displacement_type child of porous_jump_child.
    """
    z_displacement_value: z_displacement_value = z_displacement_value
    """
    z_displacement_value child of porous_jump_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .type_3 import type
from .id import id
from .normal import normal
from .partition import partition
class automatic(Group):
    """
    'automatic' child.
    """

    fluent_name = "automatic"

    child_names = \
        ['option', 'type', 'id', 'normal', 'partition']

    option: option = option
    """
    option child of automatic.
    """
    type: type = type
    """
    type child of automatic.
    """
    id: id = id
    """
    id child of automatic.
    """
    normal: normal = normal
    """
    normal child of automatic.
    """
    partition: partition = partition
    """
    partition child of automatic.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .border import border
from .bottom import bottom
from .clear_1 import clear
from .left import left
from .right_1 import right
from .top import top
from .visible_1 import visible
class axes(Group):
    """
    Enter the axes window options menu.
    """

    fluent_name = "axes"

    child_names = \
        ['border', 'bottom', 'clear', 'left', 'right', 'top', 'visible']

    border: border = border
    """
    border child of axes.
    """
    bottom: bottom = bottom
    """
    bottom child of axes.
    """
    clear: clear = clear
    """
    clear child of axes.
    """
    left: left = left
    """
    left child of axes.
    """
    right: right = right
    """
    right child of axes.
    """
    top: top = top
    """
    top child of axes.
    """
    visible: visible = visible
    """
    visible child of axes.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .species_child import species_child

class species(NamedObject[species_child], _NonCreatableNamedObjectMixin[species_child]):
    """
    'species' child.
    """

    fluent_name = "species"

    child_object_type: species_child = species_child
    """
    child_object_type of species.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .particle_drag import particle_drag
from .particle_rotation import particle_rotation
from .heat_transfer import heat_transfer
from .custom_laws import custom_laws
from .turbulent_dispersion import turbulent_dispersion
from .droplet_breakup import droplet_breakup
class physical_models(Group):
    """
    'physical_models' child.
    """

    fluent_name = "physical-models"

    child_names = \
        ['particle_drag', 'particle_rotation', 'heat_transfer', 'custom_laws',
         'turbulent_dispersion', 'droplet_breakup']

    particle_drag: particle_drag = particle_drag
    """
    particle_drag child of physical_models.
    """
    particle_rotation: particle_rotation = particle_rotation
    """
    particle_rotation child of physical_models.
    """
    heat_transfer: heat_transfer = heat_transfer
    """
    heat_transfer child of physical_models.
    """
    custom_laws: custom_laws = custom_laws
    """
    custom_laws child of physical_models.
    """
    turbulent_dispersion: turbulent_dispersion = turbulent_dispersion
    """
    turbulent_dispersion child of physical_models.
    """
    droplet_breakup: droplet_breakup = droplet_breakup
    """
    droplet_breakup child of physical_models.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .read_from_file import read_from_file
from .animation_file_name import animation_file_name
from .select_from_available import select_from_available
from .animation_name import animation_name
class read_animation(Command):
    """
    Read new animation from file or already-defined animations.
    
    Parameters
    ----------
        read_from_file : bool
            'read_from_file' child.
        animation_file_name : str
            'animation_file_name' child.
        select_from_available : bool
            'select_from_available' child.
        animation_name : str
            'animation_name' child.
    
    """

    fluent_name = "read-animation"

    argument_names = \
        ['read_from_file', 'animation_file_name', 'select_from_available',
         'animation_name']

    read_from_file: read_from_file = read_from_file
    """
    read_from_file argument of read_animation.
    """
    animation_file_name: animation_file_name = animation_file_name
    """
    animation_file_name argument of read_animation.
    """
    select_from_available: select_from_available = select_from_available
    """
    select_from_available argument of read_animation.
    """
    animation_name: animation_name = animation_name
    """
    animation_name argument of read_animation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .density_3 import density
from .specific_heat_3 import specific_heat
from .thermal_conductivity_3 import thermal_conductivity
from .thermophoretic_co import thermophoretic_co
from .scattering_factor import scattering_factor
from .emissivity import emissivity
from .viscosity_2 import viscosity
from .dpm_surften import dpm_surften
from .electric_conductivity_1 import electric_conductivity
from .dual_electric_conductivity_1 import dual_electric_conductivity
from .magnetic_permeability import magnetic_permeability
from .charge_density import charge_density
class inert_particle_child(Group):
    """
    'child_object_type' of inert_particle.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['density', 'specific_heat', 'thermal_conductivity',
         'thermophoretic_co', 'scattering_factor', 'emissivity', 'viscosity',
         'dpm_surften', 'electric_conductivity', 'dual_electric_conductivity',
         'magnetic_permeability', 'charge_density']

    density: density = density
    """
    density child of inert_particle_child.
    """
    specific_heat: specific_heat = specific_heat
    """
    specific_heat child of inert_particle_child.
    """
    thermal_conductivity: thermal_conductivity = thermal_conductivity
    """
    thermal_conductivity child of inert_particle_child.
    """
    thermophoretic_co: thermophoretic_co = thermophoretic_co
    """
    thermophoretic_co child of inert_particle_child.
    """
    scattering_factor: scattering_factor = scattering_factor
    """
    scattering_factor child of inert_particle_child.
    """
    emissivity: emissivity = emissivity
    """
    emissivity child of inert_particle_child.
    """
    viscosity: viscosity = viscosity
    """
    viscosity child of inert_particle_child.
    """
    dpm_surften: dpm_surften = dpm_surften
    """
    dpm_surften child of inert_particle_child.
    """
    electric_conductivity: electric_conductivity = electric_conductivity
    """
    electric_conductivity child of inert_particle_child.
    """
    dual_electric_conductivity: dual_electric_conductivity = dual_electric_conductivity
    """
    dual_electric_conductivity child of inert_particle_child.
    """
    magnetic_permeability: magnetic_permeability = magnetic_permeability
    """
    magnetic_permeability child of inert_particle_child.
    """
    charge_density: charge_density = charge_density
    """
    charge_density child of inert_particle_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .viscous_terms import viscous_terms
from .species_reactions import species_reactions
from .set_turbulent_viscosity_ratio import set_turbulent_viscosity_ratio
class fmg_options(Group):
    """
    Enter the full-multigrid option menu.
    """

    fluent_name = "fmg-options"

    child_names = \
        ['viscous_terms', 'species_reactions',
         'set_turbulent_viscosity_ratio']

    viscous_terms: viscous_terms = viscous_terms
    """
    viscous_terms child of fmg_options.
    """
    species_reactions: species_reactions = species_reactions
    """
    species_reactions child of fmg_options.
    """
    set_turbulent_viscosity_ratio: set_turbulent_viscosity_ratio = set_turbulent_viscosity_ratio
    """
    set_turbulent_viscosity_ratio child of fmg_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .wall_child import wall_child

class wall(NamedObject[wall_child], _NonCreatableNamedObjectMixin[wall_child]):
    """
    'wall' child.
    """

    fluent_name = "wall"

    child_object_type: wall_child = wall_child
    """
    child_object_type of wall.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name_2 import name
from .register import register
from .frequency_2 import frequency
from .active_1 import active
from .verbosity_6 import verbosity
class set(Group):
    """
    Edit a definition for automatic poor mesh numerics.
    """

    fluent_name = "set"

    child_names = \
        ['name', 'register', 'frequency', 'active', 'verbosity']

    name: name = name
    """
    name child of set.
    """
    register: register = register
    """
    register child of set.
    """
    frequency: frequency = frequency
    """
    frequency child of set.
    """
    active: active = active
    """
    active child of set.
    """
    verbosity: verbosity = verbosity
    """
    verbosity child of set.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class k_omega_model(String):
    """
    'k_omega_model' child.
    """

    fluent_name = "k-omega-model"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .planar_conductivity import planar_conductivity
from .transverse_conductivity import transverse_conductivity
class biaxial(Group):
    """
    'biaxial' child.
    """

    fluent_name = "biaxial"

    child_names = \
        ['planar_conductivity', 'transverse_conductivity']

    planar_conductivity: planar_conductivity = planar_conductivity
    """
    planar_conductivity child of biaxial.
    """
    transverse_conductivity: transverse_conductivity = transverse_conductivity
    """
    transverse_conductivity child of biaxial.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class fluid_solid_rebalance_after_read_case(Boolean):
    """
    Use optimal repartitioning after reading case file with significant solid and fluid zones.
    """

    fluent_name = "fluid-solid-rebalance-after-read-case?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .report_files import report_files
from .report_plots import report_plots
from .convergence_conditions import convergence_conditions
class monitor(Group):
    """
    'monitor' child.
    """

    fluent_name = "monitor"

    child_names = \
        ['report_files', 'report_plots', 'convergence_conditions']

    report_files: report_files = report_files
    """
    report_files child of monitor.
    """
    report_plots: report_plots = report_plots
    """
    report_plots child of monitor.
    """
    convergence_conditions: convergence_conditions = convergence_conditions
    """
    convergence_conditions child of monitor.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .averaging_coefficient import averaging_coefficient
from .binary_diffusivity import binary_diffusivity
class film_averaged(Group):
    """
    'film_averaged' child.
    """

    fluent_name = "film-averaged"

    child_names = \
        ['averaging_coefficient', 'binary_diffusivity']

    averaging_coefficient: averaging_coefficient = averaging_coefficient
    """
    averaging_coefficient child of film_averaged.
    """
    binary_diffusivity: binary_diffusivity = binary_diffusivity
    """
    binary_diffusivity child of film_averaged.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class boundary_layer_tracking(Boolean):
    """
    Enable/disable adjusting the particle timestep to account for high aspect ratio cells.
    """

    fluent_name = "boundary-layer-tracking?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class preserve_boundary_layer(Integer):
    """
    0 = Decide at runtime.
    1 = Never preserve.
    2 = Always preserve.
    """

    fluent_name = "preserve-boundary-layer"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .value import value
from .piecewise_linear import piecewise_linear
from .piecewise_polynomial import piecewise_polynomial
from .polynomial import polynomial
from .expression import expression
from .power_law import power_law
from .blottner_curve_fit import blottner_curve_fit
from .sutherland import sutherland
from .cross import cross
from .herschel_bulkley import herschel_bulkley
from .carreau import carreau
from .non_newtonian_power_law import non_newtonian_power_law
from .user_defined_function import user_defined_function
from .rgp_table import rgp_table
from .real_gas_nist import real_gas_nist
class viscosity(Group):
    """
    'viscosity' child.
    """

    fluent_name = "viscosity"

    child_names = \
        ['option', 'value', 'piecewise_linear', 'piecewise_polynomial',
         'polynomial', 'expression', 'power_law', 'blottner_curve_fit',
         'sutherland', 'cross', 'herschel_bulkley', 'carreau',
         'non_newtonian_power_law', 'user_defined_function', 'rgp_table',
         'real_gas_nist']

    option: option = option
    """
    option child of viscosity.
    """
    value: value = value
    """
    value child of viscosity.
    """
    piecewise_linear: piecewise_linear = piecewise_linear
    """
    piecewise_linear child of viscosity.
    """
    piecewise_polynomial: piecewise_polynomial = piecewise_polynomial
    """
    piecewise_polynomial child of viscosity.
    """
    polynomial: polynomial = polynomial
    """
    polynomial child of viscosity.
    """
    expression: expression = expression
    """
    expression child of viscosity.
    """
    power_law: power_law = power_law
    """
    power_law child of viscosity.
    """
    blottner_curve_fit: blottner_curve_fit = blottner_curve_fit
    """
    blottner_curve_fit child of viscosity.
    """
    sutherland: sutherland = sutherland
    """
    sutherland child of viscosity.
    """
    cross: cross = cross
    """
    cross child of viscosity.
    """
    herschel_bulkley: herschel_bulkley = herschel_bulkley
    """
    herschel_bulkley child of viscosity.
    """
    carreau: carreau = carreau
    """
    carreau child of viscosity.
    """
    non_newtonian_power_law: non_newtonian_power_law = non_newtonian_power_law
    """
    non_newtonian_power_law child of viscosity.
    """
    user_defined_function: user_defined_function = user_defined_function
    """
    user_defined_function child of viscosity.
    """
    rgp_table: rgp_table = rgp_table
    """
    rgp_table child of viscosity.
    """
    real_gas_nist: real_gas_nist = real_gas_nist
    """
    real_gas_nist child of viscosity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class retain_most_recent_files(Boolean):
    """
    After the maximum (as in max-files) is reached, a file will be deleted for each file saved.
    """

    fluent_name = "retain-most-recent-files?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .child_object_type_child import child_object_type_child

class pb_qmom(NamedObject[child_object_type_child], _CreatableNamedObjectMixin[child_object_type_child]):
    """
    'pb_qmom' child.
    """

    fluent_name = "pb-qmom"

    child_object_type: child_object_type_child = child_object_type_child
    """
    child_object_type of pb_qmom.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .amg_gpgpu_options_child import amg_gpgpu_options_child

class amg_gpgpu_options(NamedObject[amg_gpgpu_options_child], _NonCreatableNamedObjectMixin[amg_gpgpu_options_child]):
    """
    'amg_gpgpu_options' child.
    """

    fluent_name = "amg-gpgpu-options"

    child_object_type: amg_gpgpu_options_child = amg_gpgpu_options_child
    """
    child_object_type of amg_gpgpu_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .surface_list import surface_list
from .volume_list import volume_list
from .num_of_moments import num_of_moments
from .write_to_file import write_to_file
from .filename import filename
from .overwrite import overwrite
class moments(Command):
    """
    Set moments for population balance.
    
    Parameters
    ----------
        surface_list : typing.List[str]
            'surface_list' child.
        volume_list : typing.List[str]
            'volume_list' child.
        num_of_moments : int
            'num_of_moments' child.
        write_to_file : bool
            'write_to_file' child.
        filename : str
            'filename' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "moments"

    argument_names = \
        ['surface_list', 'volume_list', 'num_of_moments', 'write_to_file',
         'filename', 'overwrite']

    surface_list: surface_list = surface_list
    """
    surface_list argument of moments.
    """
    volume_list: volume_list = volume_list
    """
    volume_list argument of moments.
    """
    num_of_moments: num_of_moments = num_of_moments
    """
    num_of_moments argument of moments.
    """
    write_to_file: write_to_file = write_to_file
    """
    write_to_file argument of moments.
    """
    filename: filename = filename
    """
    filename argument of moments.
    """
    overwrite: overwrite = overwrite
    """
    overwrite argument of moments.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .single_precision_coordinates import single_precision_coordinates
from .binary_legacy_files import binary_legacy_files
from .cff_files import cff_files
from .async_optimize import async_optimize
from .write_pdat import write_pdat
from .confirm_overwrite import confirm_overwrite
from .export import export
from .import_ import import_
from .parametric_project import parametric_project
from .auto_save import auto_save
from .define_macro import define_macro
from .read_1 import read
from .read_case import read_case
from .read_case_data import read_case_data
from .read_case_setting import read_case_setting
from .read_data import read_data
from .read_mesh import read_mesh
from .read_journal import read_journal
from .start_journal import start_journal
from .stop_journal import stop_journal
from .replace_mesh import replace_mesh
from .write import write
class file(Group):
    """
    'file' child.
    """

    fluent_name = "file"

    child_names = \
        ['single_precision_coordinates', 'binary_legacy_files', 'cff_files',
         'async_optimize', 'write_pdat', 'confirm_overwrite', 'export',
         'import_', 'parametric_project']

    single_precision_coordinates: single_precision_coordinates = single_precision_coordinates
    """
    single_precision_coordinates child of file.
    """
    binary_legacy_files: binary_legacy_files = binary_legacy_files
    """
    binary_legacy_files child of file.
    """
    cff_files: cff_files = cff_files
    """
    cff_files child of file.
    """
    async_optimize: async_optimize = async_optimize
    """
    async_optimize child of file.
    """
    write_pdat: write_pdat = write_pdat
    """
    write_pdat child of file.
    """
    confirm_overwrite: confirm_overwrite = confirm_overwrite
    """
    confirm_overwrite child of file.
    """
    export: export = export
    """
    export child of file.
    """
    import_: import_ = import_
    """
    import_ child of file.
    """
    parametric_project: parametric_project = parametric_project
    """
    parametric_project child of file.
    """
    command_names = \
        ['auto_save', 'define_macro', 'read', 'read_case', 'read_case_data',
         'read_case_setting', 'read_data', 'read_mesh', 'read_journal',
         'start_journal', 'stop_journal', 'replace_mesh', 'write']

    auto_save: auto_save = auto_save
    """
    auto_save command of file.
    """
    define_macro: define_macro = define_macro
    """
    define_macro command of file.
    """
    read: read = read
    """
    read command of file.
    """
    read_case: read_case = read_case
    """
    read_case command of file.
    """
    read_case_data: read_case_data = read_case_data
    """
    read_case_data command of file.
    """
    read_case_setting: read_case_setting = read_case_setting
    """
    read_case_setting command of file.
    """
    read_data: read_data = read_data
    """
    read_data command of file.
    """
    read_mesh: read_mesh = read_mesh
    """
    read_mesh command of file.
    """
    read_journal: read_journal = read_journal
    """
    read_journal command of file.
    """
    start_journal: start_journal = start_journal
    """
    start_journal command of file.
    """
    stop_journal: stop_journal = stop_journal
    """
    stop_journal command of file.
    """
    replace_mesh: replace_mesh = replace_mesh
    """
    replace_mesh command of file.
    """
    write: write = write
    """
    write command of file.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .method import method
from .number_of_coeff import number_of_coeff
from .function_of import function_of
from .coefficients import coefficients
from .constant import constant
from .piecewise_polynomial import piecewise_polynomial
from .piecewise_linear import piecewise_linear
class dpm_bc_frictn_coeff(Group):
    """
    'dpm_bc_frictn_coeff' child.
    """

    fluent_name = "dpm-bc-frictn-coeff"

    child_names = \
        ['method', 'number_of_coeff', 'function_of', 'coefficients',
         'constant', 'piecewise_polynomial', 'piecewise_linear']

    method: method = method
    """
    method child of dpm_bc_frictn_coeff.
    """
    number_of_coeff: number_of_coeff = number_of_coeff
    """
    number_of_coeff child of dpm_bc_frictn_coeff.
    """
    function_of: function_of = function_of
    """
    function_of child of dpm_bc_frictn_coeff.
    """
    coefficients: coefficients = coefficients
    """
    coefficients child of dpm_bc_frictn_coeff.
    """
    constant: constant = constant
    """
    constant child of dpm_bc_frictn_coeff.
    """
    piecewise_polynomial: piecewise_polynomial = piecewise_polynomial
    """
    piecewise_polynomial child of dpm_bc_frictn_coeff.
    """
    piecewise_linear: piecewise_linear = piecewise_linear
    """
    piecewise_linear child of dpm_bc_frictn_coeff.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .minimum import minimum
from .maximum import maximum
from .number_of_coefficients import number_of_coefficients
from .coefficients import coefficients
class piecewise_polynomial_child(Group):
    """
    'child_object_type' of piecewise_polynomial.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['minimum', 'maximum', 'number_of_coefficients', 'coefficients']

    minimum: minimum = minimum
    """
    minimum child of piecewise_polynomial_child.
    """
    maximum: maximum = maximum
    """
    maximum child of piecewise_polynomial_child.
    """
    number_of_coefficients: number_of_coefficients = number_of_coefficients
    """
    number_of_coefficients child of piecewise_polynomial_child.
    """
    coefficients: coefficients = coefficients
    """
    coefficients child of piecewise_polynomial_child.
    """



"""Wrapper over the streaming grpc services of Fluent."""

from typing import Generator, List, Tuple


class StreamingService:
    """Class wrapping the streaming gRPC services of Fluent.

    Methods
    -------
    begin_streaming
        Begin streaming from Fluent.

    end_streaming
        End streaming
    """

    def __init__(self, stub, request, metadata: List[Tuple[str, str]]):
        self._stub = stub
        self._metadata = metadata
        self.request = request
        self._streams = None

    def begin_streaming(self, started_evt) -> Generator:
        """Begin streaming from Fluent."""
        request = self.request
        self._streams = self._stub.BeginStreaming(request, metadata=self._metadata)
        started_evt.set()
        while True:
            try:
                yield next(self._streams)
            except Exception:
                break

    def end_streaming(self) -> None:
        """End streaming from Fluent."""
        if self._streams and not self._streams.cancelled():
            self._streams.cancel()



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class variable_3(Boolean):
    """
    Use the cubic of the cumulation variable during computation of the cumulative curve.
    When the particle mass was not sampled, the diameter can be used instead.
    """

    fluent_name = "variable^3?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .theory import theory
from .wave_ht import wave_ht
from .wave_len import wave_len
from .offset_1 import offset
from .heading_angle import heading_angle
class wave_list_shallow_child(Group):
    """
    'child_object_type' of wave_list_shallow.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['theory', 'wave_ht', 'wave_len', 'offset', 'heading_angle']

    theory: theory = theory
    """
    theory child of wave_list_shallow_child.
    """
    wave_ht: wave_ht = wave_ht
    """
    wave_ht child of wave_list_shallow_child.
    """
    wave_len: wave_len = wave_len
    """
    wave_len child of wave_list_shallow_child.
    """
    offset: offset = offset
    """
    offset child of wave_list_shallow_child.
    """
    heading_angle: heading_angle = heading_angle
    """
    heading_angle child of wave_list_shallow_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class film_phase_change_model(String):
    """
    'film_phase_change_model' child.
    """

    fluent_name = "film-phase-change-model"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .skewness_correction_itr_count import skewness_correction_itr_count
from .neighbor_correction_itr_count import neighbor_correction_itr_count
from .skewness_neighbor_coupling import skewness_neighbor_coupling
from .vof_correction_itr_count import vof_correction_itr_count
from .explicit_momentum_under_relaxation import explicit_momentum_under_relaxation
from .explicit_pressure_under_relaxation import explicit_pressure_under_relaxation
from .flow_courant_number import flow_courant_number
from .volume_fraction_courant_number import volume_fraction_courant_number
from .explicit_volume_fraction_under_relaxation import explicit_volume_fraction_under_relaxation
class p_v_controls(Group):
    """
    'p_v_controls' child.
    """

    fluent_name = "p-v-controls"

    child_names = \
        ['skewness_correction_itr_count', 'neighbor_correction_itr_count',
         'skewness_neighbor_coupling', 'vof_correction_itr_count',
         'explicit_momentum_under_relaxation',
         'explicit_pressure_under_relaxation', 'flow_courant_number',
         'volume_fraction_courant_number',
         'explicit_volume_fraction_under_relaxation']

    skewness_correction_itr_count: skewness_correction_itr_count = skewness_correction_itr_count
    """
    skewness_correction_itr_count child of p_v_controls.
    """
    neighbor_correction_itr_count: neighbor_correction_itr_count = neighbor_correction_itr_count
    """
    neighbor_correction_itr_count child of p_v_controls.
    """
    skewness_neighbor_coupling: skewness_neighbor_coupling = skewness_neighbor_coupling
    """
    skewness_neighbor_coupling child of p_v_controls.
    """
    vof_correction_itr_count: vof_correction_itr_count = vof_correction_itr_count
    """
    vof_correction_itr_count child of p_v_controls.
    """
    explicit_momentum_under_relaxation: explicit_momentum_under_relaxation = explicit_momentum_under_relaxation
    """
    explicit_momentum_under_relaxation child of p_v_controls.
    """
    explicit_pressure_under_relaxation: explicit_pressure_under_relaxation = explicit_pressure_under_relaxation
    """
    explicit_pressure_under_relaxation child of p_v_controls.
    """
    flow_courant_number: flow_courant_number = flow_courant_number
    """
    flow_courant_number child of p_v_controls.
    """
    volume_fraction_courant_number: volume_fraction_courant_number = volume_fraction_courant_number
    """
    volume_fraction_courant_number child of p_v_controls.
    """
    explicit_volume_fraction_under_relaxation: explicit_volume_fraction_under_relaxation = explicit_volume_fraction_under_relaxation
    """
    explicit_volume_fraction_under_relaxation child of p_v_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class auto_time_size_calc_solid_zone(Boolean):
    """
    Enable/disable automatic time step size calculation for solid zone.
    """

    fluent_name = "auto-time-size-calc-solid-zone?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .reset_statistics import reset_statistics
from .statistics_controls import statistics_controls
class statistics(Group):
    """
    Specify statistics parameter of sampling and averaging of flow and optical quantiies.
    """

    fluent_name = "statistics"

    child_names = \
        ['reset_statistics']

    reset_statistics: reset_statistics = reset_statistics
    """
    reset_statistics child of statistics.
    """
    command_names = \
        ['statistics_controls']

    statistics_controls: statistics_controls = statistics_controls
    """
    statistics_controls command of statistics.
    """



"""Wrapper over the health check grpc service of Fluent."""

from enum import Enum
from typing import List, Tuple

import grpc

from ansys.api.fluent.v0 import health_pb2 as HealthCheckModule
from ansys.api.fluent.v0 import health_pb2_grpc as HealthCheckGrpcModule
from ansys.fluent.core.services.error_handler import catch_grpc_error


class HealthCheckService:
    """Class wrapping the health check gRPC service of Fluent.

    Methods
    -------
    check_health
        Check the health of the Fluent connection.
    """

    class Status(Enum):
        UNKNOWN = 0
        SERVING = 1
        NOT_SERVING = 2
        SERVICE_UNKNOWN = 3

    def __init__(self, channel: grpc.Channel, metadata: List[Tuple[str, str]]):
        self._stub = HealthCheckGrpcModule.HealthStub(channel)
        self._metadata = metadata
        self._channel = channel

    @catch_grpc_error
    def check_health(self) -> str:
        """Check the health of the Fluent connection.

        Returns
        -------
        str
            "SERVING" or "NOT_SERVING"
        """
        request = HealthCheckModule.HealthCheckRequest()
        response = self._stub.Check(request, metadata=self._metadata)
        return HealthCheckService.Status(response.status).name

    @catch_grpc_error
    def wait_for_server(self, timeout) -> None:
        """Keeps a watch on the health of the Fluent connection.

        Response changes only when the service's serving status changes.
        """
        request = HealthCheckModule.HealthCheckRequest()
        responses = self._stub.Watch(request, metadata=self._metadata, timeout=timeout)

        while True:
            try:
                response = next(responses)
                if response.status == 1:
                    responses.cancel()
            except StopIteration:
                break
            except Exception as e:
                if e.code() == grpc.StatusCode.CANCELLED:
                    break
                if e.code() == grpc.StatusCode.DEADLINE_EXCEEDED:
                    raise TimeoutError(
                        f"The connection to the Fluent server could not be established within the configurable {timeout} second time limit."
                    )
                raise

    def status(self) -> str:
        """Check health of Fluent connection."""
        if self._channel:
            try:
                return self.check_health()
            except Exception:
                return self.Status.NOT_SERVING.name
        else:
            return self.Status.NOT_SERVING.name

    @property
    def is_serving(self) -> bool:
        return True if self.status() == "SERVING" else False



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .droplet_particle_child import droplet_particle_child

class mixture_species(NamedObject[droplet_particle_child], _NonCreatableNamedObjectMixin[droplet_particle_child]):
    """
    'mixture_species' child.
    """

    fluent_name = "mixture-species"

    child_object_type: droplet_particle_child = droplet_particle_child
    """
    child_object_type of mixture_species.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class prandtl_tuning_coefficient(Real):
    """
    Set the tuning coefficient in modified prandtl tip loss model:.
    """

    fluent_name = "prandtl-tuning-coefficient"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .geom_disable import geom_disable
from .geom_dir_spec import geom_dir_spec
from .geom_dir_x import geom_dir_x
from .geom_dir_y import geom_dir_y
from .geom_dir_z import geom_dir_z
from .geom_levels import geom_levels
from .geom_bgthread import geom_bgthread
from .angular import angular
from .p_jump import p_jump
from .ai import ai
from .aj import aj
from .ak import ak
from .x_origin import x_origin
from .y_origin import y_origin
from .z_origin import z_origin
from .shift_x import shift_x
from .shift_y import shift_y
from .shift_z import shift_z
from .per_angle import per_angle
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'angular', 'p_jump',
         'ai', 'aj', 'ak', 'x_origin', 'y_origin', 'z_origin', 'shift_x',
         'shift_y', 'shift_z', 'per_angle']

    geom_disable: geom_disable = geom_disable
    """
    geom_disable child of phase_child.
    """
    geom_dir_spec: geom_dir_spec = geom_dir_spec
    """
    geom_dir_spec child of phase_child.
    """
    geom_dir_x: geom_dir_x = geom_dir_x
    """
    geom_dir_x child of phase_child.
    """
    geom_dir_y: geom_dir_y = geom_dir_y
    """
    geom_dir_y child of phase_child.
    """
    geom_dir_z: geom_dir_z = geom_dir_z
    """
    geom_dir_z child of phase_child.
    """
    geom_levels: geom_levels = geom_levels
    """
    geom_levels child of phase_child.
    """
    geom_bgthread: geom_bgthread = geom_bgthread
    """
    geom_bgthread child of phase_child.
    """
    angular: angular = angular
    """
    angular child of phase_child.
    """
    p_jump: p_jump = p_jump
    """
    p_jump child of phase_child.
    """
    ai: ai = ai
    """
    ai child of phase_child.
    """
    aj: aj = aj
    """
    aj child of phase_child.
    """
    ak: ak = ak
    """
    ak child of phase_child.
    """
    x_origin: x_origin = x_origin
    """
    x_origin child of phase_child.
    """
    y_origin: y_origin = y_origin
    """
    y_origin child of phase_child.
    """
    z_origin: z_origin = z_origin
    """
    z_origin child of phase_child.
    """
    shift_x: shift_x = shift_x
    """
    shift_x child of phase_child.
    """
    shift_y: shift_y = shift_y
    """
    shift_y child of phase_child.
    """
    shift_z: shift_z = shift_z
    """
    shift_z child of phase_child.
    """
    per_angle: per_angle = per_angle
    """
    per_angle child of phase_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class initial_values_to_ignore(Integer):
    """
    'initial_values_to_ignore' child.
    """

    fluent_name = "initial-values-to-ignore"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .report_name import report_name
class delete_simulation_report(Command):
    """
    Delete the provided simulation report.
    
    Parameters
    ----------
        report_name : str
            'report_name' child.
    
    """

    fluent_name = "delete-simulation-report"

    argument_names = \
        ['report_name']

    report_name: report_name = report_name
    """
    report_name argument of delete_simulation_report.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .volume_child import volume_child

class volume(NamedObject[volume_child], _CreatableNamedObjectMixin[volume_child]):
    """
    'volume' child.
    """

    fluent_name = "volume"

    child_object_type: volume_child = volume_child
    """
    child_object_type of volume.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .pressure_gradient_force import pressure_gradient_force
from .virtual_mass_force import virtual_mass_force
from .volume_displacement_1 import volume_displacement
from .wall_film import wall_film
class physical_models(Group):
    """
    Main menu to enable the required physical submodels for the discrete phase model.
    """

    fluent_name = "physical-models"

    child_names = \
        ['pressure_gradient_force', 'virtual_mass_force',
         'volume_displacement', 'wall_film']

    pressure_gradient_force: pressure_gradient_force = pressure_gradient_force
    """
    pressure_gradient_force child of physical_models.
    """
    virtual_mass_force: virtual_mass_force = virtual_mass_force
    """
    virtual_mass_force child of physical_models.
    """
    volume_displacement: volume_displacement = volume_displacement
    """
    volume_displacement child of physical_models.
    """
    wall_film: wall_film = wall_film
    """
    wall_film child of physical_models.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .interior_child import interior_child

class interior(NamedObject[interior_child], _NonCreatableNamedObjectMixin[interior_child]):
    """
    'interior' child.
    """

    fluent_name = "interior"

    child_object_type: interior_child = interior_child
    """
    child_object_type of interior.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .turb_visc_func_mf_child import turb_visc_func_mf_child

class pb_disc_bc(NamedObject[turb_visc_func_mf_child], _NonCreatableNamedObjectMixin[turb_visc_func_mf_child]):
    """
    'pb_disc_bc' child.
    """

    fluent_name = "pb-disc-bc"

    child_object_type: turb_visc_func_mf_child = turb_visc_func_mf_child
    """
    child_object_type of pb_disc_bc.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class enable_expert_view(Boolean):
    """
    Enable/disable the display of non-standard ("expert-level") DPM TUI options.
    """

    fluent_name = "enable-expert-view?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .type import type
from .two_dim_space import two_dim_space
from .velocity_formulation import velocity_formulation
from .time import time
class solver(Group):
    """
    'solver' child.
    """

    fluent_name = "solver"

    child_names = \
        ['type', 'two_dim_space', 'velocity_formulation', 'time']

    type: type = type
    """
    type child of solver.
    """
    two_dim_space: two_dim_space = two_dim_space
    """
    two_dim_space child of solver.
    """
    velocity_formulation: velocity_formulation = velocity_formulation
    """
    velocity_formulation child of solver.
    """
    time: time = time
    """
    time child of solver.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .fluid_child import fluid_child

class inert_particle(NamedObject[fluid_child], _CreatableNamedObjectMixin[fluid_child]):
    """
    'inert_particle' child.
    """

    fluent_name = "inert-particle"

    child_object_type: fluid_child = fluid_child
    """
    child_object_type of inert_particle.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class first_to_second_order_blending(Real):
    """
    1st-order to higher-order blending factor [min=0.0 - max=1.0].
    """

    fluent_name = "first-to-second-order-blending"




"""Wrappers over TUI-based datamodel gRPC service of Fluent."""

import keyword
import types
from typing import Any, Dict, Iterable, List, Tuple, Union

from google.protobuf.json_format import MessageToDict
import grpc

from ansys.api.fluent.v0 import datamodel_tui_pb2 as DataModelProtoModule
from ansys.api.fluent.v0 import datamodel_tui_pb2_grpc as DataModelGrpcModule
from ansys.api.fluent.v0.variant_pb2 import Variant
from ansys.fluent.core.services.error_handler import catch_grpc_error
from ansys.fluent.core.services.interceptors import TracingInterceptor

Path = List[str]


class DatamodelService:
    """Class wrapping the TUI-based datamodel gRPC service of Fluent.

    Using the methods from PyMenu class is recommended.
    """

    def __init__(self, channel: grpc.Channel, metadata: List[Tuple[str, str]]):
        tracing_interceptor = TracingInterceptor()
        intercept_channel = grpc.intercept_channel(channel, tracing_interceptor)
        self.__stub = DataModelGrpcModule.DataModelStub(intercept_channel)
        self.__metadata = metadata

    @catch_grpc_error
    def get_attribute_value(
        self, request: DataModelProtoModule.GetAttributeValueRequest
    ) -> DataModelProtoModule.GetAttributeValueResponse:
        return self.__stub.GetAttributeValue(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_state(
        self, request: DataModelProtoModule.GetStateRequest
    ) -> DataModelProtoModule.GetStateResponse:
        return self.__stub.GetState(request, metadata=self.__metadata)

    @catch_grpc_error
    def set_state(
        self, request: DataModelProtoModule.SetStateRequest
    ) -> DataModelProtoModule.SetStateResponse:
        return self.__stub.SetState(request, metadata=self.__metadata)

    @catch_grpc_error
    def execute_command(
        self, request: DataModelProtoModule.ExecuteCommandRequest
    ) -> DataModelProtoModule.ExecuteCommandResponse:
        return self.__stub.ExecuteCommand(request, metadata=self.__metadata)

    @catch_grpc_error
    def execute_query(
        self, request: DataModelProtoModule.ExecuteQueryRequest
    ) -> DataModelProtoModule.ExecuteQueryResponse:
        return self.__stub.ExecuteQuery(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_static_info(self, request):
        return self.__stub.GetStaticInfo(request, metadata=self.__metadata)


def _convert_value_to_gvalue(val: Any, gval: Variant):
    """Convert Python datatype to Value type of
    google/protobuf/struct.proto."""
    if isinstance(val, bool):
        gval.bool_value = val
    elif isinstance(val, int) or isinstance(val, float):
        gval.number_value = val
    elif isinstance(val, str):
        gval.string_value = val
    elif isinstance(val, list) or isinstance(val, tuple):
        # set the one_of to list_value
        gval.list_value.values.add()
        gval.list_value.values.pop()
        for item in val:
            item_gval = gval.list_value.values.add()
            _convert_value_to_gvalue(item, item_gval)
    elif isinstance(val, dict):
        for k, v in val.items():
            _convert_value_to_gvalue(v, gval.struct_value.fields[k])


def _convert_gvalue_to_value(gval: Variant):
    """Convert Value type of google/protobuf/struct.proto to Python
    datatype."""
    if gval.HasField("bool_value"):
        return gval.bool_value
    elif gval.HasField("number_value"):
        return gval.number_value
    elif gval.HasField("string_value"):
        return gval.string_value
    elif gval.HasField("list_value"):
        val = []
        for item in gval.list_value.values:
            val.append(_convert_gvalue_to_value(item))
        return val
    elif gval.HasField("struct_value"):
        val = {}
        for k, v in gval.struct_value.fields.items():
            val[k] = _convert_gvalue_to_value(v)
        return val


class PyMenu:
    """Pythonic wrapper of TUI-based DatamodelService class. Use this class
    instead of directly calling the DatamodelService's method.

    Methods
    -------
    get_child_names(include_unavailable):
        Get child menu names.
    execute(*args, **kwargs)
        Execute a command or query at a menu with positional or keyword
        arguments.
    get_doc_string(include_unavailable)
        Get docstring for a menu.
    """

    def __init__(self, service: DatamodelService, path: Union[Path, str]):
        self._service = service
        self._path = path if isinstance(path, str) else convert_path_to_grpc_path(path)

    def get_child_names(self, include_unavailable: bool = False) -> List[str]:
        """Get the names of child menus.

        Parameters
        ----------
        include_unavailable : bool, optional
            Whether to query over static TUI metadata. The default is ``False``.

        Returns
        -------
        List[str]
            Names of child menus.
        """
        request = DataModelProtoModule.GetAttributeValueRequest()
        request.path = self._path
        request.attribute = DataModelProtoModule.Attribute.CHILD_NAMES
        if include_unavailable:
            request.args["include_unavailable"] = 1
        response = self._service.get_attribute_value(request)
        return _convert_gvalue_to_value(response.value)

    def _execute_command(
        self, request: DataModelProtoModule.ExecuteCommandRequest
    ) -> Any:
        ret = self._service.execute_command(request)
        return _convert_gvalue_to_value(ret.result)

    def _execute_query(
        self, request: DataModelProtoModule.ExecuteCommandRequest
    ) -> Any:
        ret = self._service.execute_query(request)
        return _convert_gvalue_to_value(ret.result)

    def execute(self, *args, **kwargs) -> Any:
        """Execute a command or query at a path with positional or keyword
        arguments.

        Parameters
        ----------

        Returns
        -------
        Any
            Query result (any Python datatype) or Future object
            wrapping TUI output of a command.
        """
        request = DataModelProtoModule.ExecuteCommandRequest()
        request.path = self._path
        if kwargs:
            for k, v in kwargs.items():
                _convert_value_to_gvalue(v, request.args.fields[k])
        else:
            _convert_value_to_gvalue(args, request.args.fields["tui_args"])
        if self._path.startswith("/query/"):
            return self._execute_query(request)
        else:
            return self._execute_command(request)

    def get_doc_string(self, include_unavailable: bool = False) -> str:
        """Get docstring for a menu.

        Parameters
        ----------
        include_unavailable : bool, optional
            Whether to query over static TUI metadata. The default is ``False``.

        Returns
        -------
        str
        """
        request = DataModelProtoModule.GetAttributeValueRequest()
        request.path = self._path
        request.attribute = DataModelProtoModule.Attribute.HELP_STRING
        if include_unavailable:
            request.args["include_unavailable"] = 1
        response = self._service.get_attribute_value(request)
        return _convert_gvalue_to_value(response.value)

    def get_static_info(self) -> Dict[str, Any]:
        """Get static info at menu level.

        Returns
        -------
        DataModelProtoModule.StaticInfo
            static info
        """
        try:
            request = DataModelProtoModule.GetStaticInfoRequest()
            request.path = self._path
            response = self._service.get_static_info(request)
            return MessageToDict(response.info, including_default_value_fields=True)
        except RuntimeError:
            return _get_static_info_at_level(self)


def _get_static_info_at_level(menu: PyMenu) -> Dict[str, Any]:
    info = {}
    info["help"] = menu.get_doc_string(include_unavailable=True)
    info["menus"] = {}
    info["commands"] = {}
    child_names = menu.get_child_names(include_unavailable=True)
    if child_names:
        for child_name in child_names:
            if child_name:
                child_menu = PyMenu(
                    menu._service,
                    menu._path + ("" if menu._path.endswith("/") else "/") + child_name,
                )
                child_info = _get_static_info_at_level(child_menu)
                if child_info.pop("is_command", False):
                    info["commands"][child_name] = child_info
                else:
                    info["menus"][child_name] = child_info
    else:
        info["is_command"] = True
    return info


class TUIMenu:
    """Base class for the generated menu classes."""

    def __init__(self, path, service):
        self.path = path
        self.service = service

    def __dir__(self) -> Iterable[str]:
        return [
            convert_tui_menu_to_func_name(x)
            for x in PyMenu(self.service, self.path).get_child_names()
        ]

    def __getattribute__(self, name):
        attr = super().__getattribute__(name)
        if type(attr) == types.MethodType:
            path = self.path + [name]
            # if menus are inserted at runtime in Fluent
            if PyMenu(self.service, path).get_child_names():
                return TUIMenuGeneric(path, self.service)
        return attr


class TUIMenuGeneric(TUIMenu):
    """Generic menu class for when the explicit menu classes aren't
    available."""

    def __getattribute__(self, name):
        if name in ["path", "service"]:
            return super().__getattribute__(name)
        name = convert_func_name_to_tui_menu(name)
        path = self.path + [name]
        if PyMenu(self.service, path).get_child_names():
            return TUIMenuGeneric(path, self.service)
        else:
            return TUICommandGeneric(path, self.service)


class TUICommandGeneric(TUIMenu):
    """Generic command class for when the explicit menu classes aren't
    available."""

    def __call__(self, *args, **kwargs):
        return PyMenu(self.service, self.path).execute(*args, **kwargs)


def convert_func_name_to_tui_menu(func_name: str) -> str:
    """Convert a Python function name to a TUI menu string.

    Parameters
    ----------
    func_name : str
       Name of the Python function.

    Returns
    -------
    str
    """
    if func_name.endswith("_") and keyword.iskeyword(func_name[:-1]):
        return func_name[:-1]
    return func_name


def convert_tui_menu_to_func_name(menu: str) -> str:
    """Convert a TUI menu string to a Python function name.

    Parameters
    ----------
    menu : str
       TUI menu string.

    Returns
    -------
    str
    """
    if keyword.iskeyword(menu):
        return menu + "_"
    if menu.endswith("[beta]"):
        menu = menu[:-6]
    menu = menu.rstrip("?")
    return menu


def convert_path_to_grpc_path(path: Path) -> str:
    """Convert a path structure to a string that can be passed to the data
    model gRPC service.

    Parameters
    ----------
    path : Path
        Path structure.

    Returns
    -------
    str
        gRPC path.
    """
    return "/" + "/".join(convert_func_name_to_tui_menu(x) for x in path)



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .r import r
from .u import u
class matrix(Group):
    """
    'matrix' child.
    """

    fluent_name = "matrix"

    child_names = \
        ['r', 'u']

    r: r = r
    """
    r child of matrix.
    """
    u: u = u
    """
    u child of matrix.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .n_smooth_for_interfacial_regims import n_smooth_for_interfacial_regims
from .sm_relax_factor import sm_relax_factor
from .viscous_func_options import viscous_func_options
from .density_func_options import density_func_options
from .exponent_smoothing_func import exponent_smoothing_func
from .exponent_density_func import exponent_density_func
from .boundry_treatment import boundry_treatment
from .near_wall_treatment_1 import near_wall_treatment
class interfacial_artificial_viscosity(Group):
    """
    Interfacial artifical viscosity controls.
    """

    fluent_name = "interfacial-artificial-viscosity"

    child_names = \
        ['n_smooth_for_interfacial_regims', 'sm_relax_factor',
         'viscous_func_options', 'density_func_options',
         'exponent_smoothing_func', 'exponent_density_func',
         'boundry_treatment', 'near_wall_treatment']

    n_smooth_for_interfacial_regims: n_smooth_for_interfacial_regims = n_smooth_for_interfacial_regims
    """
    n_smooth_for_interfacial_regims child of interfacial_artificial_viscosity.
    """
    sm_relax_factor: sm_relax_factor = sm_relax_factor
    """
    sm_relax_factor child of interfacial_artificial_viscosity.
    """
    viscous_func_options: viscous_func_options = viscous_func_options
    """
    viscous_func_options child of interfacial_artificial_viscosity.
    """
    density_func_options: density_func_options = density_func_options
    """
    density_func_options child of interfacial_artificial_viscosity.
    """
    exponent_smoothing_func: exponent_smoothing_func = exponent_smoothing_func
    """
    exponent_smoothing_func child of interfacial_artificial_viscosity.
    """
    exponent_density_func: exponent_density_func = exponent_density_func
    """
    exponent_density_func child of interfacial_artificial_viscosity.
    """
    boundry_treatment: boundry_treatment = boundry_treatment
    """
    boundry_treatment child of interfacial_artificial_viscosity.
    """
    near_wall_treatment: near_wall_treatment = near_wall_treatment
    """
    near_wall_treatment child of interfacial_artificial_viscosity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .type_1 import type
class projection(Command):
    """
    Set the camera projection.
    
    Parameters
    ----------
        type : str
            'type' child.
    
    """

    fluent_name = "projection"

    argument_names = \
        ['type']

    type: type = type
    """
    type argument of projection.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable_1 import enable
from .dt_init_limit import dt_init_limit
from .dt_max import dt_max
from .dt_factor_min import dt_factor_min
from .dt_factor_max import dt_factor_max
from .max_velocity_ratio import max_velocity_ratio
class auto_dt_advanced_controls(Group):
    """
    'auto_dt_advanced_controls' child.
    """

    fluent_name = "auto-dt-advanced-controls"

    child_names = \
        ['enable', 'dt_init_limit', 'dt_max', 'dt_factor_min',
         'dt_factor_max', 'max_velocity_ratio']

    enable: enable = enable
    """
    enable child of auto_dt_advanced_controls.
    """
    dt_init_limit: dt_init_limit = dt_init_limit
    """
    dt_init_limit child of auto_dt_advanced_controls.
    """
    dt_max: dt_max = dt_max
    """
    dt_max child of auto_dt_advanced_controls.
    """
    dt_factor_min: dt_factor_min = dt_factor_min
    """
    dt_factor_min child of auto_dt_advanced_controls.
    """
    dt_factor_max: dt_factor_max = dt_factor_max
    """
    dt_factor_max child of auto_dt_advanced_controls.
    """
    max_velocity_ratio: max_velocity_ratio = max_velocity_ratio
    """
    max_velocity_ratio child of auto_dt_advanced_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class lighting_interpolation(String):
    """
    Set lighting interpolation method.
    Use Phong shading to interpolate the normals for each pixel of a polygon and compute a color at every pixel.
    Use Gouraud shading to calculate the color at each vertex of a polygon and interpolate it in the interior.
    Use flat shading for meshes and polygons.
    """

    fluent_name = "lighting-interpolation"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class display_adaption_cells(Command):
    """
    Display cells marked for refinement/coarsening.
    """

    fluent_name = "display-adaption-cells"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .change_type import change_type
from .exhaust_fan_child import exhaust_fan_child

class exhaust_fan(NamedObject[exhaust_fan_child], _CreatableNamedObjectMixin[exhaust_fan_child]):
    """
    'exhaust_fan' child.
    """

    fluent_name = "exhaust-fan"

    command_names = \
        ['change_type']

    change_type: change_type = change_type
    """
    change_type command of exhaust_fan.
    """
    child_object_type: exhaust_fan_child = exhaust_fan_child
    """
    child_object_type of exhaust_fan.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .crossflow_transition import crossflow_transition
from .critical_reynolds_number_correlation import critical_reynolds_number_correlation
from .clambda_scale import clambda_scale
from .capg_hightu import capg_hightu
from .cfpg_hightu import cfpg_hightu
from .capg_lowtu import capg_lowtu
from .cfpg_lowtu import cfpg_lowtu
from .ctu_hightu import ctu_hightu
from .ctu_lowtu import ctu_lowtu
from .rec_max import rec_max
from .rec_c1 import rec_c1
from .rec_c2 import rec_c2
from .cbubble_c1 import cbubble_c1
from .cbubble_c2 import cbubble_c2
from .rv1_switch import rv1_switch
class transition_model_options(Group):
    """
    'transition_model_options' child.
    """

    fluent_name = "transition-model-options"

    child_names = \
        ['crossflow_transition', 'critical_reynolds_number_correlation',
         'clambda_scale', 'capg_hightu', 'cfpg_hightu', 'capg_lowtu',
         'cfpg_lowtu', 'ctu_hightu', 'ctu_lowtu', 'rec_max', 'rec_c1',
         'rec_c2', 'cbubble_c1', 'cbubble_c2', 'rv1_switch']

    crossflow_transition: crossflow_transition = crossflow_transition
    """
    crossflow_transition child of transition_model_options.
    """
    critical_reynolds_number_correlation: critical_reynolds_number_correlation = critical_reynolds_number_correlation
    """
    critical_reynolds_number_correlation child of transition_model_options.
    """
    clambda_scale: clambda_scale = clambda_scale
    """
    clambda_scale child of transition_model_options.
    """
    capg_hightu: capg_hightu = capg_hightu
    """
    capg_hightu child of transition_model_options.
    """
    cfpg_hightu: cfpg_hightu = cfpg_hightu
    """
    cfpg_hightu child of transition_model_options.
    """
    capg_lowtu: capg_lowtu = capg_lowtu
    """
    capg_lowtu child of transition_model_options.
    """
    cfpg_lowtu: cfpg_lowtu = cfpg_lowtu
    """
    cfpg_lowtu child of transition_model_options.
    """
    ctu_hightu: ctu_hightu = ctu_hightu
    """
    ctu_hightu child of transition_model_options.
    """
    ctu_lowtu: ctu_lowtu = ctu_lowtu
    """
    ctu_lowtu child of transition_model_options.
    """
    rec_max: rec_max = rec_max
    """
    rec_max child of transition_model_options.
    """
    rec_c1: rec_c1 = rec_c1
    """
    rec_c1 child of transition_model_options.
    """
    rec_c2: rec_c2 = rec_c2
    """
    rec_c2 child of transition_model_options.
    """
    cbubble_c1: cbubble_c1 = cbubble_c1
    """
    cbubble_c1 child of transition_model_options.
    """
    cbubble_c2: cbubble_c2 = cbubble_c2
    """
    cbubble_c2 child of transition_model_options.
    """
    rv1_switch: rv1_switch = rv1_switch
    """
    rv1_switch child of transition_model_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .pole_real import pole_real
from .pole_imag import pole_imag
from .amplitude_real import amplitude_real
from .amplitude_imag import amplitude_imag
class impedance_2_child(Group):
    """
    'child_object_type' of impedance_2.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['pole_real', 'pole_imag', 'amplitude_real', 'amplitude_imag']

    pole_real: pole_real = pole_real
    """
    pole_real child of impedance_2_child.
    """
    pole_imag: pole_imag = pole_imag
    """
    pole_imag child of impedance_2_child.
    """
    amplitude_real: amplitude_real = amplitude_real
    """
    amplitude_real child of impedance_2_child.
    """
    amplitude_imag: amplitude_imag = amplitude_imag
    """
    amplitude_imag child of impedance_2_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .flux_auto_select import flux_auto_select
from .flux_type_1 import flux_type
class pbns_cases(Group):
    """
    'pbns_cases' child.
    """

    fluent_name = "pbns_cases"

    child_names = \
        ['flux_auto_select', 'flux_type']

    flux_auto_select: flux_auto_select = flux_auto_select
    """
    flux_auto_select child of pbns_cases.
    """
    flux_type: flux_type = flux_type
    """
    flux_type child of pbns_cases.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enabled_2 import enabled
from .user_defined_timestep import user_defined_timestep
from .error_tolerance import error_tolerance
from .time_end import time_end
from .min_time_step import min_time_step
from .max_time_step import max_time_step
from .min_step_change_factor import min_step_change_factor
from .max_step_change_factor import max_step_change_factor
from .fixed_time_steps import fixed_time_steps
class adaptive_time_stepping(Group):
    """
    'adaptive_time_stepping' child.
    """

    fluent_name = "adaptive-time-stepping"

    child_names = \
        ['enabled', 'user_defined_timestep', 'error_tolerance', 'time_end',
         'min_time_step', 'max_time_step', 'min_step_change_factor',
         'max_step_change_factor', 'fixed_time_steps']

    enabled: enabled = enabled
    """
    enabled child of adaptive_time_stepping.
    """
    user_defined_timestep: user_defined_timestep = user_defined_timestep
    """
    user_defined_timestep child of adaptive_time_stepping.
    """
    error_tolerance: error_tolerance = error_tolerance
    """
    error_tolerance child of adaptive_time_stepping.
    """
    time_end: time_end = time_end
    """
    time_end child of adaptive_time_stepping.
    """
    min_time_step: min_time_step = min_time_step
    """
    min_time_step child of adaptive_time_stepping.
    """
    max_time_step: max_time_step = max_time_step
    """
    max_time_step child of adaptive_time_stepping.
    """
    min_step_change_factor: min_step_change_factor = min_step_change_factor
    """
    min_step_change_factor child of adaptive_time_stepping.
    """
    max_step_change_factor: max_step_change_factor = max_step_change_factor
    """
    max_step_change_factor child of adaptive_time_stepping.
    """
    fixed_time_steps: fixed_time_steps = fixed_time_steps
    """
    fixed_time_steps child of adaptive_time_stepping.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .initialize_1 import initialize
from .duplicate import duplicate
from .set_as_current import set_as_current
from .use_base_data import use_base_data
from .export_design_table import export_design_table
from .import_design_table import import_design_table
from .parametric_studies_child import parametric_studies_child

class parametric_studies(NamedObject[parametric_studies_child], _CreatableNamedObjectMixin[parametric_studies_child]):
    """
    'parametric_studies' child.
    """

    fluent_name = "parametric-studies"

    command_names = \
        ['initialize', 'duplicate', 'set_as_current', 'use_base_data',
         'export_design_table', 'import_design_table']

    initialize: initialize = initialize
    """
    initialize command of parametric_studies.
    """
    duplicate: duplicate = duplicate
    """
    duplicate command of parametric_studies.
    """
    set_as_current: set_as_current = set_as_current
    """
    set_as_current command of parametric_studies.
    """
    use_base_data: use_base_data = use_base_data
    """
    use_base_data command of parametric_studies.
    """
    export_design_table: export_design_table = export_design_table
    """
    export_design_table command of parametric_studies.
    """
    import_design_table: import_design_table = import_design_table
    """
    import_design_table command of parametric_studies.
    """
    child_object_type: parametric_studies_child = parametric_studies_child
    """
    child_object_type of parametric_studies.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class use_legacy_particle_location_method(Boolean):
    """
    Enable/disable legacy method of locating particles in cells.
    """

    fluent_name = "use-legacy-particle-location-method?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .cell_function_1 import cell_function
from .load_distribution import load_distribution
from .merge import merge
from .partition_origin_vector import partition_origin_vector
from .pre_test_1 import pre_test
from .smooth_1 import smooth
from .print_verbosity import print_verbosity
from .origin import origin
from .laplace_smoothing import laplace_smoothing
from .nfaces_as_weights_1 import nfaces_as_weights
from .face_area_as_weights import face_area_as_weights
from .layering import layering
from .solid_thread_weight import solid_thread_weight
from .stretched_mesh_enhancement import stretched_mesh_enhancement
from .particle_weight import particle_weight
from .vof_free_surface_weight import vof_free_surface_weight
from .isat_weight import isat_weight
from .fluid_solid_rebalance_after_read_case import fluid_solid_rebalance_after_read_case
from .model_weighted_partition import model_weighted_partition
from .dpm_load_balancing import dpm_load_balancing
from .across_zones_1 import across_zones
from .all_off import all_off
from .all_on import all_on
class set(Group):
    """
    Enter the menu to set partition parameters.
    """

    fluent_name = "set"

    child_names = \
        ['cell_function', 'load_distribution', 'merge',
         'partition_origin_vector', 'pre_test', 'smooth', 'print_verbosity',
         'origin', 'laplace_smoothing', 'nfaces_as_weights',
         'face_area_as_weights', 'layering', 'solid_thread_weight',
         'stretched_mesh_enhancement', 'particle_weight',
         'vof_free_surface_weight', 'isat_weight',
         'fluid_solid_rebalance_after_read_case', 'model_weighted_partition',
         'dpm_load_balancing']

    cell_function: cell_function = cell_function
    """
    cell_function child of set.
    """
    load_distribution: load_distribution = load_distribution
    """
    load_distribution child of set.
    """
    merge: merge = merge
    """
    merge child of set.
    """
    partition_origin_vector: partition_origin_vector = partition_origin_vector
    """
    partition_origin_vector child of set.
    """
    pre_test: pre_test = pre_test
    """
    pre_test child of set.
    """
    smooth: smooth = smooth
    """
    smooth child of set.
    """
    print_verbosity: print_verbosity = print_verbosity
    """
    print_verbosity child of set.
    """
    origin: origin = origin
    """
    origin child of set.
    """
    laplace_smoothing: laplace_smoothing = laplace_smoothing
    """
    laplace_smoothing child of set.
    """
    nfaces_as_weights: nfaces_as_weights = nfaces_as_weights
    """
    nfaces_as_weights child of set.
    """
    face_area_as_weights: face_area_as_weights = face_area_as_weights
    """
    face_area_as_weights child of set.
    """
    layering: layering = layering
    """
    layering child of set.
    """
    solid_thread_weight: solid_thread_weight = solid_thread_weight
    """
    solid_thread_weight child of set.
    """
    stretched_mesh_enhancement: stretched_mesh_enhancement = stretched_mesh_enhancement
    """
    stretched_mesh_enhancement child of set.
    """
    particle_weight: particle_weight = particle_weight
    """
    particle_weight child of set.
    """
    vof_free_surface_weight: vof_free_surface_weight = vof_free_surface_weight
    """
    vof_free_surface_weight child of set.
    """
    isat_weight: isat_weight = isat_weight
    """
    isat_weight child of set.
    """
    fluid_solid_rebalance_after_read_case: fluid_solid_rebalance_after_read_case = fluid_solid_rebalance_after_read_case
    """
    fluid_solid_rebalance_after_read_case child of set.
    """
    model_weighted_partition: model_weighted_partition = model_weighted_partition
    """
    model_weighted_partition child of set.
    """
    dpm_load_balancing: dpm_load_balancing = dpm_load_balancing
    """
    dpm_load_balancing child of set.
    """
    command_names = \
        ['across_zones', 'all_off', 'all_on']

    across_zones: across_zones = across_zones
    """
    across_zones command of set.
    """
    all_off: all_off = all_off
    """
    all_off command of set.
    """
    all_on: all_on = all_on
    """
    all_on command of set.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .file import file
from .setup import setup
from .solution import solution
from .results import results
from .parametric_studies import parametric_studies
from .current_parametric_study import current_parametric_study
class root(Group):
    """
    'root' object.
    """

    fluent_name = ""

    child_names = \
        ['file', 'setup', 'solution', 'results', 'parametric_studies',
         'current_parametric_study']

    file: file = file
    """
    file child of root.
    """
    setup: setup = setup
    """
    setup child of root.
    """
    solution: solution = solution
    """
    solution child of root.
    """
    results: results = results
    """
    results child of root.
    """
    parametric_studies: parametric_studies = parametric_studies
    """
    parametric_studies child of root.
    """
    current_parametric_study: current_parametric_study = current_parametric_study
    """
    current_parametric_study child of root.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .pre_exponential_factor import pre_exponential_factor
from .activation_energy import activation_energy
class particle_thermolysis_rate(Group):
    """
    'particle_thermolysis_rate' child.
    """

    fluent_name = "particle-thermolysis-rate"

    child_names = \
        ['pre_exponential_factor', 'activation_energy']

    pre_exponential_factor: pre_exponential_factor = pre_exponential_factor
    """
    pre_exponential_factor child of particle_thermolysis_rate.
    """
    activation_energy: activation_energy = activation_energy
    """
    activation_energy child of particle_thermolysis_rate.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .multi_level_grid import multi_level_grid
from .residual_reduction_level import residual_reduction_level
from .cycle_count import cycle_count
class customize_fmg_initialization(Command):
    """
    'customize_fmg_initialization' command.
    
    Parameters
    ----------
        multi_level_grid : int
            'multi_level_grid' child.
        residual_reduction_level : typing.List[real]
            'residual_reduction_level' child.
        cycle_count : typing.List[real]
            'cycle_count' child.
    
    """

    fluent_name = "customize-fmg-initialization"

    argument_names = \
        ['multi_level_grid', 'residual_reduction_level', 'cycle_count']

    multi_level_grid: multi_level_grid = multi_level_grid
    """
    multi_level_grid argument of customize_fmg_initialization.
    """
    residual_reduction_level: residual_reduction_level = residual_reduction_level
    """
    residual_reduction_level argument of customize_fmg_initialization.
    """
    cycle_count: cycle_count = cycle_count
    """
    cycle_count argument of customize_fmg_initialization.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .sample_var import sample_var
from .min_val import min_val
class set_minimum(Command):
    """
    Set the minimum value of the range to be considered for a specific variable in the data reduction.
    
    Parameters
    ----------
        sample_var : str
            'sample_var' child.
        min_val : real
            'min_val' child.
    
    """

    fluent_name = "set-minimum"

    argument_names = \
        ['sample_var', 'min_val']

    sample_var: sample_var = sample_var
    """
    sample_var argument of set_minimum.
    """
    min_val: min_val = min_val
    """
    min_val argument of set_minimum.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name_1 import name
from .field import field
from .vector_field import vector_field
from .surfaces_list import surfaces_list
from .surfaces import surfaces
from .lic_color_by_field import lic_color_by_field
from .lic_color import lic_color
from .lic_oriented import lic_oriented
from .lic_normalize import lic_normalize
from .lic_pixel_interpolation import lic_pixel_interpolation
from .lic_max_steps import lic_max_steps
from .texture_spacing import texture_spacing
from .texture_size import texture_size
from .lic_intensity_factor import lic_intensity_factor
from .lic_image_filter import lic_image_filter
from .lic_intensity_alpha import lic_intensity_alpha
from .lic_fast import lic_fast
from .gray_scale import gray_scale
from .image_to_display import image_to_display
from .range_option import range_option
from .color_map import color_map
from .draw_mesh import draw_mesh
from .mesh_object import mesh_object
from .display_state_name import display_state_name
from .display_2 import display
class lic_child(Group):
    """
    'child_object_type' of lic.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'field', 'vector_field', 'surfaces_list', 'surfaces',
         'lic_color_by_field', 'lic_color', 'lic_oriented', 'lic_normalize',
         'lic_pixel_interpolation', 'lic_max_steps', 'texture_spacing',
         'texture_size', 'lic_intensity_factor', 'lic_image_filter',
         'lic_intensity_alpha', 'lic_fast', 'gray_scale', 'image_to_display',
         'range_option', 'color_map', 'draw_mesh', 'mesh_object',
         'display_state_name']

    name: name = name
    """
    name child of lic_child.
    """
    field: field = field
    """
    field child of lic_child.
    """
    vector_field: vector_field = vector_field
    """
    vector_field child of lic_child.
    """
    surfaces_list: surfaces_list = surfaces_list
    """
    surfaces_list child of lic_child.
    """
    surfaces: surfaces = surfaces
    """
    surfaces child of lic_child.
    """
    lic_color_by_field: lic_color_by_field = lic_color_by_field
    """
    lic_color_by_field child of lic_child.
    """
    lic_color: lic_color = lic_color
    """
    lic_color child of lic_child.
    """
    lic_oriented: lic_oriented = lic_oriented
    """
    lic_oriented child of lic_child.
    """
    lic_normalize: lic_normalize = lic_normalize
    """
    lic_normalize child of lic_child.
    """
    lic_pixel_interpolation: lic_pixel_interpolation = lic_pixel_interpolation
    """
    lic_pixel_interpolation child of lic_child.
    """
    lic_max_steps: lic_max_steps = lic_max_steps
    """
    lic_max_steps child of lic_child.
    """
    texture_spacing: texture_spacing = texture_spacing
    """
    texture_spacing child of lic_child.
    """
    texture_size: texture_size = texture_size
    """
    texture_size child of lic_child.
    """
    lic_intensity_factor: lic_intensity_factor = lic_intensity_factor
    """
    lic_intensity_factor child of lic_child.
    """
    lic_image_filter: lic_image_filter = lic_image_filter
    """
    lic_image_filter child of lic_child.
    """
    lic_intensity_alpha: lic_intensity_alpha = lic_intensity_alpha
    """
    lic_intensity_alpha child of lic_child.
    """
    lic_fast: lic_fast = lic_fast
    """
    lic_fast child of lic_child.
    """
    gray_scale: gray_scale = gray_scale
    """
    gray_scale child of lic_child.
    """
    image_to_display: image_to_display = image_to_display
    """
    image_to_display child of lic_child.
    """
    range_option: range_option = range_option
    """
    range_option child of lic_child.
    """
    color_map: color_map = color_map
    """
    color_map child of lic_child.
    """
    draw_mesh: draw_mesh = draw_mesh
    """
    draw_mesh child of lic_child.
    """
    mesh_object: mesh_object = mesh_object
    """
    mesh_object child of lic_child.
    """
    display_state_name: display_state_name = display_state_name
    """
    display_state_name child of lic_child.
    """
    command_names = \
        ['display']

    display: display = display
    """
    display command of lic_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .max_coarse_levels import max_coarse_levels
from .coarsen_by_interval import coarsen_by_interval
from .conservative_coarsening import conservative_coarsening
from .aggressive_coarsening import aggressive_coarsening
from .laplace_coarsening import laplace_coarsening
class coarsening_parameters(Group):
    """
    'coarsening_parameters' child.
    """

    fluent_name = "coarsening-parameters"

    child_names = \
        ['max_coarse_levels', 'coarsen_by_interval',
         'conservative_coarsening', 'aggressive_coarsening',
         'laplace_coarsening']

    max_coarse_levels: max_coarse_levels = max_coarse_levels
    """
    max_coarse_levels child of coarsening_parameters.
    """
    coarsen_by_interval: coarsen_by_interval = coarsen_by_interval
    """
    coarsen_by_interval child of coarsening_parameters.
    """
    conservative_coarsening: conservative_coarsening = conservative_coarsening
    """
    conservative_coarsening child of coarsening_parameters.
    """
    aggressive_coarsening: aggressive_coarsening = aggressive_coarsening
    """
    aggressive_coarsening child of coarsening_parameters.
    """
    laplace_coarsening: laplace_coarsening = laplace_coarsening
    """
    laplace_coarsening child of coarsening_parameters.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .visible import visible
from .size import size
from .color import color
from .log_scale import log_scale
from .format import format
from .user_skip import user_skip
from .show_all import show_all
from .position import position
from .font_name import font_name
from .font_automatic import font_automatic
from .font_size import font_size
from .length_1 import length
from .width import width
class color_map(Group):
    """
    'color_map' child.
    """

    fluent_name = "color-map"

    child_names = \
        ['visible', 'size', 'color', 'log_scale', 'format', 'user_skip',
         'show_all', 'position', 'font_name', 'font_automatic', 'font_size',
         'length', 'width']

    visible: visible = visible
    """
    visible child of color_map.
    """
    size: size = size
    """
    size child of color_map.
    """
    color: color = color
    """
    color child of color_map.
    """
    log_scale: log_scale = log_scale
    """
    log_scale child of color_map.
    """
    format: format = format
    """
    format child of color_map.
    """
    user_skip: user_skip = user_skip
    """
    user_skip child of color_map.
    """
    show_all: show_all = show_all
    """
    show_all child of color_map.
    """
    position: position = position
    """
    position child of color_map.
    """
    font_name: font_name = font_name
    """
    font_name child of color_map.
    """
    font_automatic: font_automatic = font_automatic
    """
    font_automatic child of color_map.
    """
    font_size: font_size = font_size
    """
    font_size child of color_map.
    """
    length: length = length
    """
    length child of color_map.
    """
    width: width = width
    """
    width child of color_map.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .first_to_second_order_blending import first_to_second_order_blending
from .first_to_second_order_blending_list import first_to_second_order_blending_list
from .scheme import scheme
from .flow_skew_diffusion_exclude import flow_skew_diffusion_exclude
from .scalars_skew_diffusion_exclude import scalars_skew_diffusion_exclude
from .rhie_chow_flux_specify import rhie_chow_flux_specify
from .rhie_chow_method import rhie_chow_method
class spatial(Group):
    """
    'spatial' child.
    """

    fluent_name = "spatial"

    child_names = \
        ['first_to_second_order_blending',
         'first_to_second_order_blending_list', 'scheme',
         'flow_skew_diffusion_exclude', 'scalars_skew_diffusion_exclude',
         'rhie_chow_flux_specify', 'rhie_chow_method']

    first_to_second_order_blending: first_to_second_order_blending = first_to_second_order_blending
    """
    first_to_second_order_blending child of spatial.
    """
    first_to_second_order_blending_list: first_to_second_order_blending_list = first_to_second_order_blending_list
    """
    first_to_second_order_blending_list child of spatial.
    """
    scheme: scheme = scheme
    """
    scheme child of spatial.
    """
    flow_skew_diffusion_exclude: flow_skew_diffusion_exclude = flow_skew_diffusion_exclude
    """
    flow_skew_diffusion_exclude child of spatial.
    """
    scalars_skew_diffusion_exclude: scalars_skew_diffusion_exclude = scalars_skew_diffusion_exclude
    """
    scalars_skew_diffusion_exclude child of spatial.
    """
    rhie_chow_flux_specify: rhie_chow_flux_specify = rhie_chow_flux_specify
    """
    rhie_chow_flux_specify child of spatial.
    """
    rhie_chow_method: rhie_chow_method = rhie_chow_method
    """
    rhie_chow_method child of spatial.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable_1 import enable
from .disable import disable
from .print import print
from .clear import clear
class profile(Group):
    """
    Enter the adaption profile menu.
    """

    fluent_name = "profile"

    command_names = \
        ['enable', 'disable', 'print', 'clear']

    enable: enable = enable
    """
    enable command of profile.
    """
    disable: disable = disable
    """
    disable command of profile.
    """
    print: print = print
    """
    print command of profile.
    """
    clear: clear = clear
    """
    clear command of profile.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name_1 import name
from .uid import uid
from .options_7 import options
from .filter_settings import filter_settings
from .range import range
from .style_attribute_1 import style_attribute
from .vector_settings import vector_settings
from .plot_1 import plot
from .track_single_particle_stream import track_single_particle_stream
from .skip import skip
from .coarsen import coarsen
from .field import field
from .injections_list import injections_list
from .free_stream_particles import free_stream_particles
from .wall_film_particles import wall_film_particles
from .track_pdf_particles import track_pdf_particles
from .color_map import color_map
from .draw_mesh import draw_mesh
from .mesh_object import mesh_object
from .display_state_name import display_state_name
from .axes import axes
from .curves import curves
from .display_2 import display
class particle_track_child(Group):
    """
    'child_object_type' of particle_track.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'uid', 'options', 'filter_settings', 'range',
         'style_attribute', 'vector_settings', 'plot',
         'track_single_particle_stream', 'skip', 'coarsen', 'field',
         'injections_list', 'free_stream_particles', 'wall_film_particles',
         'track_pdf_particles', 'color_map', 'draw_mesh', 'mesh_object',
         'display_state_name', 'axes', 'curves']

    name: name = name
    """
    name child of particle_track_child.
    """
    uid: uid = uid
    """
    uid child of particle_track_child.
    """
    options: options = options
    """
    options child of particle_track_child.
    """
    filter_settings: filter_settings = filter_settings
    """
    filter_settings child of particle_track_child.
    """
    range: range = range
    """
    range child of particle_track_child.
    """
    style_attribute: style_attribute = style_attribute
    """
    style_attribute child of particle_track_child.
    """
    vector_settings: vector_settings = vector_settings
    """
    vector_settings child of particle_track_child.
    """
    plot: plot = plot
    """
    plot child of particle_track_child.
    """
    track_single_particle_stream: track_single_particle_stream = track_single_particle_stream
    """
    track_single_particle_stream child of particle_track_child.
    """
    skip: skip = skip
    """
    skip child of particle_track_child.
    """
    coarsen: coarsen = coarsen
    """
    coarsen child of particle_track_child.
    """
    field: field = field
    """
    field child of particle_track_child.
    """
    injections_list: injections_list = injections_list
    """
    injections_list child of particle_track_child.
    """
    free_stream_particles: free_stream_particles = free_stream_particles
    """
    free_stream_particles child of particle_track_child.
    """
    wall_film_particles: wall_film_particles = wall_film_particles
    """
    wall_film_particles child of particle_track_child.
    """
    track_pdf_particles: track_pdf_particles = track_pdf_particles
    """
    track_pdf_particles child of particle_track_child.
    """
    color_map: color_map = color_map
    """
    color_map child of particle_track_child.
    """
    draw_mesh: draw_mesh = draw_mesh
    """
    draw_mesh child of particle_track_child.
    """
    mesh_object: mesh_object = mesh_object
    """
    mesh_object child of particle_track_child.
    """
    display_state_name: display_state_name = display_state_name
    """
    display_state_name child of particle_track_child.
    """
    axes: axes = axes
    """
    axes child of particle_track_child.
    """
    curves: curves = curves
    """
    curves child of particle_track_child.
    """
    command_names = \
        ['display']

    display: display = display
    """
    display command of particle_track_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .reset_color import reset_color
class reset(Command):
    """
    To reset colors and/or materials to the defaults.
    
    Parameters
    ----------
        reset_color : bool
            'reset_color' child.
    
    """

    fluent_name = "reset?"

    argument_names = \
        ['reset_color']

    reset_color: reset_color = reset_color
    """
    reset_color argument of reset.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .udf_cf_names import udf_cf_names
class setup_unsteady_statistics(Command):
    """
    'setup_unsteady_statistics' command.
    
    Parameters
    ----------
        udf_cf_names : typing.List[str]
            'udf_cf_names' child.
    
    """

    fluent_name = "setup-unsteady-statistics"

    argument_names = \
        ['udf_cf_names']

    udf_cf_names: udf_cf_names = udf_cf_names
    """
    udf_cf_names argument of setup_unsteady_statistics.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class max_iter_per_timestep_count(Integer):
    """
    Specify maximum number of iterations per timestep.
    """

    fluent_name = "max-iter-per-timestep-count"




import os
from pathlib import Path
import socket
import subprocess
import tempfile
import time
from typing import List

from ansys.fluent.core.session import parse_server_info_file


def _get_free_port() -> int:
    sock = socket.socket()
    sock.bind(("", 0))
    return sock.getsockname()[1]


def start_fluent_container(mounted_from: str, mounted_to: str, args: List[str]) -> int:
    """Start a Fluent container.

    Parameters
    ----------
    mounted_from : str
        Path to mount from. Within the container, ``mounted_from`` is mounted as
        ``mount_to``.
    mounted_to : str
        Path to mount to. Within the container, ``mounted_from`` is mounted as
        ``mount_to``.
    args : List[str]
        List of Fluent launch arguments.

    Returns
    -------
    int
        gPRC server port exposed from the container.
    """
    fd, sifile = tempfile.mkstemp(suffix=".txt", prefix="serverinfo-", dir=mounted_from)
    os.close(fd)
    timeout = 100
    license_server = os.environ["ANSYSLMD_LICENSE_FILE"]
    port = _get_free_port()
    password = ""
    container_sifile = mounted_to + "/" + Path(sifile).name
    image_tag = os.getenv("FLUENT_IMAGE_TAG", "v22.2.0")
    test_name = os.getenv("PYFLUENT_TEST_NAME", "none")

    try:
        subprocess.run(
            [
                "docker",
                "run",
                "-d",
                "--rm",
                "-p",
                f"{port}:{port}",
                "-v",
                f"{mounted_from}:{mounted_to}",
                "-e",
                f"ANSYSLMD_LICENSE_FILE={license_server}",
                "-e",
                f"REMOTING_PORTS={port}/portspan=2",
                "-l",
                f"test_name={test_name}",
                f"ghcr.io/pyansys/pyfluent:{image_tag}",
                "-gu",
                f"-sifile={container_sifile}",
            ]
            + args
        )

        sifile_last_mtime = os.stat(sifile).st_mtime
        while True:
            if os.stat(sifile).st_mtime > sifile_last_mtime:
                time.sleep(1)
                _, _, password = parse_server_info_file(sifile)
                break
            if timeout == 0:
                break
            time.sleep(1)
            timeout -= 1
        return port, password
    except OSError:
        pass
    finally:
        if os.path.exists(sifile):
            os.remove(sifile)



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable_node_based_averaging import enable_node_based_averaging
from .average_source_terms import average_source_terms
from .average_every_step import average_every_step
from .averaging_kernel import averaging_kernel
class averaging(Group):
    """
    Menu containing options to enable/disable node-based averaging of DPM variables and DPM source terms. 
    Please note that node-based averaging functionality is only available if source term linearization is not active.
    """

    fluent_name = "averaging"

    child_names = \
        ['enable_node_based_averaging', 'average_source_terms',
         'average_every_step', 'averaging_kernel']

    enable_node_based_averaging: enable_node_based_averaging = enable_node_based_averaging
    """
    enable_node_based_averaging child of averaging.
    """
    average_source_terms: average_source_terms = average_source_terms
    """
    average_source_terms child of averaging.
    """
    average_every_step: average_every_step = average_every_step
    """
    average_every_step child of averaging.
    """
    averaging_kernel: averaging_kernel = averaging_kernel
    """
    averaging_kernel child of averaging.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .density_4 import density
from .thermal_conductivity_3 import thermal_conductivity
from .latent_heat_1 import latent_heat
from .volatile_fraction import volatile_fraction
from .combustible_fraction import combustible_fraction
from .swelling_coefficient import swelling_coefficient
from .burn_stoichiometry import burn_stoichiometry
from .specific_heat_3 import specific_heat
from .binary_diffusivity import binary_diffusivity
from .diffusivity_reference_pressure import diffusivity_reference_pressure
from .vaporization_temperature import vaporization_temperature
from .thermophoretic_co import thermophoretic_co
from .burn_hreact import burn_hreact
from .burn_hreact_fraction import burn_hreact_fraction
from .devolatilization_model import devolatilization_model
from .combustion_model import combustion_model
from .scattering_factor_1 import scattering_factor
from .emissivity_1 import emissivity
class combusting_particle_child(Group):
    """
    'child_object_type' of combusting_particle.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['density', 'thermal_conductivity', 'latent_heat',
         'volatile_fraction', 'combustible_fraction', 'swelling_coefficient',
         'burn_stoichiometry', 'specific_heat', 'binary_diffusivity',
         'diffusivity_reference_pressure', 'vaporization_temperature',
         'thermophoretic_co', 'burn_hreact', 'burn_hreact_fraction',
         'devolatilization_model', 'combustion_model', 'scattering_factor',
         'emissivity']

    density: density = density
    """
    density child of combusting_particle_child.
    """
    thermal_conductivity: thermal_conductivity = thermal_conductivity
    """
    thermal_conductivity child of combusting_particle_child.
    """
    latent_heat: latent_heat = latent_heat
    """
    latent_heat child of combusting_particle_child.
    """
    volatile_fraction: volatile_fraction = volatile_fraction
    """
    volatile_fraction child of combusting_particle_child.
    """
    combustible_fraction: combustible_fraction = combustible_fraction
    """
    combustible_fraction child of combusting_particle_child.
    """
    swelling_coefficient: swelling_coefficient = swelling_coefficient
    """
    swelling_coefficient child of combusting_particle_child.
    """
    burn_stoichiometry: burn_stoichiometry = burn_stoichiometry
    """
    burn_stoichiometry child of combusting_particle_child.
    """
    specific_heat: specific_heat = specific_heat
    """
    specific_heat child of combusting_particle_child.
    """
    binary_diffusivity: binary_diffusivity = binary_diffusivity
    """
    binary_diffusivity child of combusting_particle_child.
    """
    diffusivity_reference_pressure: diffusivity_reference_pressure = diffusivity_reference_pressure
    """
    diffusivity_reference_pressure child of combusting_particle_child.
    """
    vaporization_temperature: vaporization_temperature = vaporization_temperature
    """
    vaporization_temperature child of combusting_particle_child.
    """
    thermophoretic_co: thermophoretic_co = thermophoretic_co
    """
    thermophoretic_co child of combusting_particle_child.
    """
    burn_hreact: burn_hreact = burn_hreact
    """
    burn_hreact child of combusting_particle_child.
    """
    burn_hreact_fraction: burn_hreact_fraction = burn_hreact_fraction
    """
    burn_hreact_fraction child of combusting_particle_child.
    """
    devolatilization_model: devolatilization_model = devolatilization_model
    """
    devolatilization_model child of combusting_particle_child.
    """
    combustion_model: combustion_model = combustion_model
    """
    combustion_model child of combusting_particle_child.
    """
    scattering_factor: scattering_factor = scattering_factor
    """
    scattering_factor child of combusting_particle_child.
    """
    emissivity: emissivity = emissivity
    """
    emissivity child of combusting_particle_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class pressure_max_lim(Real):
    """
    Set maximum allowable absolute pressure.
    """

    fluent_name = "pressure-max-lim"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .all import all
from .feature import feature
from .outline import outline
class edge_type(Group):
    """
    'edge_type' child.
    """

    fluent_name = "edge-type"

    child_names = \
        ['option', 'all', 'feature', 'outline']

    option: option = option
    """
    option child of edge_type.
    """
    all: all = all
    """
    all child of edge_type.
    """
    feature: feature = feature
    """
    feature child of edge_type.
    """
    outline: outline = outline
    """
    outline child of edge_type.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class time_step_size_for_solid_zone(Real):
    """
    Pseudo Time Step Size for solid zones.
    """

    fluent_name = "time-step-size-for-solid-zone"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .mean_and_std_deviation import mean_and_std_deviation
from .pb_disc_components import pb_disc_components
class pb_disc(Group):
    """
    'pb_disc' child.
    """

    fluent_name = "pb-disc"

    child_names = \
        ['mean_and_std_deviation', 'pb_disc_components']

    mean_and_std_deviation: mean_and_std_deviation = mean_and_std_deviation
    """
    mean_and_std_deviation child of pb_disc.
    """
    pb_disc_components: pb_disc_components = pb_disc_components
    """
    pb_disc_components child of pb_disc.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .wall_function_1 import wall_function
from .law_of_the_wall import law_of_the_wall
from .enhanced_wall_treatment_options import enhanced_wall_treatment_options
from .wall_omega_treatment import wall_omega_treatment
class near_wall_treatment(Group):
    """
    'near_wall_treatment' child.
    """

    fluent_name = "near-wall-treatment"

    child_names = \
        ['wall_function', 'law_of_the_wall',
         'enhanced_wall_treatment_options', 'wall_omega_treatment']

    wall_function: wall_function = wall_function
    """
    wall_function child of near_wall_treatment.
    """
    law_of_the_wall: law_of_the_wall = law_of_the_wall
    """
    law_of_the_wall child of near_wall_treatment.
    """
    enhanced_wall_treatment_options: enhanced_wall_treatment_options = enhanced_wall_treatment_options
    """
    enhanced_wall_treatment_options child of near_wall_treatment.
    """
    wall_omega_treatment: wall_omega_treatment = wall_omega_treatment
    """
    wall_omega_treatment child of near_wall_treatment.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class subgrid_turbulence_contribution_aiad(Boolean):
    """
    Enable/disable the Subgrid Turbulence Contribution for the AIAD model.
    """

    fluent_name = "subgrid-turbulence-contribution-aiad?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class color_filter(String):
    """
    Set the color filter options for the picture.
    """

    fluent_name = "color-filter"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .axis_direction_child import axis_direction_child

class under_relaxation(NamedObject[axis_direction_child], _NonCreatableNamedObjectMixin[axis_direction_child]):
    """
    Enter Under Relaxation Menu.
    """

    fluent_name = "under-relaxation"

    child_object_type: axis_direction_child = axis_direction_child
    """
    child_object_type of under_relaxation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .aeromechanics_child import aeromechanics_child

class aeromechanics(NamedObject[aeromechanics_child], _CreatableNamedObjectMixin[aeromechanics_child]):
    """
    'aeromechanics' child.
    """

    fluent_name = "aeromechanics"

    child_object_type: aeromechanics_child = aeromechanics_child
    """
    child_object_type of aeromechanics.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .correction_tolerance_child import correction_tolerance_child

class correction_tolerance(NamedObject[correction_tolerance_child], _NonCreatableNamedObjectMixin[correction_tolerance_child]):
    """
    'correction_tolerance' child.
    """

    fluent_name = "correction-tolerance"

    child_object_type: correction_tolerance_child = correction_tolerance_child
    """
    child_object_type of correction_tolerance.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .flow_scheme import flow_scheme
from .coupled_form import coupled_form
from .solve_n_phase import solve_n_phase
class p_v_coupling(Group):
    """
    'p_v_coupling' child.
    """

    fluent_name = "p-v-coupling"

    child_names = \
        ['flow_scheme', 'coupled_form', 'solve_n_phase']

    flow_scheme: flow_scheme = flow_scheme
    """
    flow_scheme child of p_v_coupling.
    """
    coupled_form: coupled_form = coupled_form
    """
    coupled_form child of p_v_coupling.
    """
    solve_n_phase: solve_n_phase = solve_n_phase
    """
    solve_n_phase child of p_v_coupling.
    """
